@@ -1,6 +1,6 @@
 # SPDX-License-Identifier: Apache-2.0
 
-# Copyright 2020 igo95862
+# Copyright 2020, 2021 igo95862
 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,15 +13,46 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+from __future__ import annotations
 
-from setuptools import setup, Extension
+from os import environ
+
+from setuptools import Extension, setup
+
+from sys import platform
+
+if environ.get('CFLAGS') is None:
+    if platform == "darwin":
+        environ['CFLAGS'] = (
+            "-Wextra -Wconversion -Wall")
+    else:
+        environ['CFLAGS'] = (
+            "-Werror "
+            "-Wextra -Wconversion -Wall")
+
+if environ.get('LDFLAGS') is None:
+    if platform == "darwin":
+        environ['LDFLAGS'] = "-Wl,-all_load"
+    else:
+        environ['LDFLAGS'] = "-Wl,--no-as-needed"
 
 setup(
     name="notcurses",
-    version="2.0.2",
+    version="2.3.13",
     packages=['notcurses'],
     ext_modules=[
-        Extension('notcurses/_notcurses', ['notcurses/_notcurses.c']),
+        Extension(
+            name='notcurses.notcurses',
+            sources=[
+                'notcurses/channels.c',
+                'notcurses/context.c',
+                'notcurses/main.c',
+                'notcurses/misc.c',
+                'notcurses/plane.c',
+            ],
+            libraries=['notcurses'],
+            language='c',
+        ),
     ],
     author="Nick Black",
     author_email="nickblack@linux.com",
@@ -38,4 +69,9 @@ setup(
         'Natural Language :: English',
         'Programming Language :: Python',
     ],
+    package_data={
+        'notcurses': [
+            'py.typed',
+        ],
+    }
 )
