@@ -1,36 +1,37 @@
 //! `NcDirect`
 
-// --- ---------------------------------------------------------
-// col 0:
-// --------------
-//          4  X: wont do
-//             ~: WIP
+// total: 62
+// ---------------------------------------------------
+// (X)  1 : wont do
+// (~)  3 : TODO / WIP
 //
-// col 1: 43
-// --------------
-//         39  f: ffi function imported by bindgen
-//             F: ffi function wrapped safely
-//          4  r: static function reimplemented in Rust
+// (f) 46 : unsafe ffi function exported by bindgen
+// (w)  1 : safely wrapped ffi function
+// (r) 11 : static function manually reimplemented
 //
-// col 2: 43
-// --------------
-//         41  m: impl as an `NcDirect` method
-//          2  M: impl for the `DirectMode` wrapper struct too
-//
-// col 3:
-// --------------
-//             t: tests done for the ffi or reimplemented funtion
-//             T: tests done also for the m method
-//             Ŧ: tests done also for the M method wrapper struct
-// --- ---------------------------------------------------------
+// (m) 55 : method implemented
 //
+// (t)  0 : unit test done for the function
+// (T)  0 : unit test done also for the method
+// ---------------------------------------------------
 // fm  ncdirect_bg_default
 // fm  ncdirect_bg_palindex
 // fm  ncdirect_bg_rgb
 // fm  ncdirect_box
+// rm  ncdirect_canbraille
+// rm  ncdirect_canchangecolor
+// fm  ncdirect_canget_cursor
+// rm  ncdirect_canfade
+// rm  ncdirect_canhalfblock
 // fm  ncdirect_canopen_images
+// rm  ncdirect_canopen_videos
+// rm  ncdirect_canquadrant
+// rm  ncdirect_cantruecolor
 // fm  ncdirect_canutf8
+// wm  ncdirect_capabilities
+// fm  ncdirect_check_pixel_support
 // fm  ncdirect_clear
+//~f   ncdirect_core_init
 // fm  ncdirect_cursor_disable
 // fm  ncdirect_cursor_down
 // fm  ncdirect_cursor_enable
@@ -41,6 +42,7 @@
 // fm  ncdirect_cursor_right
 // fm  ncdirect_cursor_up
 // fm  ncdirect_cursor_yx
+// fm  ncdirect_detected_terminal
 // fm  ncdirect_dim_x
 // fm  ncdirect_dim_y
 // fm  ncdirect_double_box
@@ -49,43 +51,41 @@
 // fm  ncdirect_fg_rgb
 // fm  ncdirect_flush
 // fm  ncdirect_getc
+//~r   ncdirect_heavy_box,
 // fm  ncdirect_hline_interp
-// fM  ncdirect_init
+// fm  ncdirect_init
 // fm  ncdirect_inputready_fd
+//~r   ncdirect_light_box,
 // fm  ncplane_on_styles
 // fm  ncplane_off_styles
 // fm  ncdirect_palette_size
 //X    ncdirect_printf_aligned
 // fm  ncdirect_putstr
 // fm  ncdirect_raster_frame
+// fm  ncdirect_readline
 // fm  ncdirect_render_frame
 // fm  ncdirect_render_image
 // fm  ncdirect_rounded_box
 // fm  ncplane_set_styles
-// fM  ncdirect_stop
-//X    ncdirect_styles_off     // deprecated
-//X    ncdirect_styles_on      // deprecated
-//X    ncdirect_styles_set     // deprecated
+// fm  ncdirect_stop
+// f   ncdirect_stream
+// f   ncdirect_styles
+// f   ncdirect_supported_styles
 // fm  ncdirect_vline_interp
-//
-// rm ncdirect_bg_rgb8
-// rm ncdirect_fg_rgb8
-// rm ncdirect_getc_nblock
-// rm ncdirect_getc_nblocking
+// rm  ncdirect_bg_rgb8
+// rm  ncdirect_fg_rgb8
+// rm  ncdirect_getc_nblock
+// rm  ncdirect_getc_nblocking
 
 #[cfg(test)]
 mod test;
 
 mod methods;
 mod reimplemented;
-mod wrapper;
 
 pub use reimplemented::*;
-pub use wrapper::*;
 
 /// Minimal notcurses instance for styling text.
-///
-/// This is the internal type safely wrapped by [DirectMode].
 pub type NcDirect = crate::bindings::ffi::ncdirect;
 
 /// Flags (options) for [`NcDirect`]
@@ -113,3 +113,13 @@ pub const NCDIRECT_OPTION_INHIBIT_SETLOCALE: NcDirectFlags =
 /// signal handlers.
 pub const NCDIRECT_OPTION_NO_QUIT_SIGHANDLERS: NcDirectFlags =
     crate::bindings::ffi::NCDIRECT_OPTION_NO_QUIT_SIGHANDLERS as NcDirectFlags;
+
+/// Flag that enables showing detailed information.
+pub const NCDIRECT_OPTION_VERBOSE: NcDirectFlags =
+    crate::bindings::ffi::NCDIRECT_OPTION_VERBOSE as NcDirectFlags;
+
+/// Flag that enables showing all diagnostics (equivalent to
+/// [`NCLOGLEVEL_TRACE`][crate::NCLOGLEVEL_TRACE]).
+/// Implies [`NCDIRECT_OPTION_VERBOSE`].
+pub const NCDIRECT_OPTION_VERY_VERBOSE: NcDirectFlags =
+    crate::bindings::ffi::NCDIRECT_OPTION_VERY_VERBOSE as NcDirectFlags;
