@@ -11,7 +11,7 @@
 
 use std::ffi::c_void;
 
-use crate::{NcIntResult, NcPlane, NcTime, Notcurses};
+use crate::{Nc, NcIntResult, NcPlane, NcTime};
 
 /// Called for each fade iteration on the NcPlane.
 ///
@@ -19,9 +19,8 @@ use crate::{NcIntResult, NcPlane, NcTime, Notcurses};
 /// and that value is propagated out.
 ///
 /// The recommended absolute display time target is passed in 'tspec'.
-pub type NcFadeCb = Option<
-    unsafe extern "C" fn(*mut Notcurses, *mut NcPlane, *const NcTime, *mut c_void) -> NcIntResult,
->;
+pub type NcFadeCb =
+    Option<unsafe extern "C" fn(*mut Nc, *mut NcPlane, *const NcTime, *mut c_void) -> NcIntResult>;
 
 /// Context for a palette fade operation
 pub type NcFadeCtx = crate::bindings::ffi::ncfadectx;
@@ -32,7 +31,7 @@ impl NcFadeCtx {
     /// Rather than the simple ncplane_fade{in/out}(),
     /// ncfadectx_setup() can be paired with a loop over
     /// ncplane_fade{in/out}_iteration() + ncfadectx_free().
-    pub fn setup<'a>(plane: &'a mut NcPlane) -> &'a mut NcFadeCtx {
+    pub fn setup(plane: &mut NcPlane) -> &mut NcFadeCtx {
         unsafe { &mut *crate::ncfadectx_setup(plane) }
     }
 
