@@ -1,11 +1,11 @@
 //! `NcPlane`
 
-// functions already exported by bindgen : 108 (5 + 103)
-// -----------------------------------------------------
-// (X) wont:  6
+// functions already exported by bindgen : 117
+// -------------------------------------------
+// (X) wont: 10
 // (D) depr:  4
 // (#) test: 13
-// (W) wrap: 79 of 98
+// (W) wrap: 83
 // -------------------------------------------
 //W  ncpile_bottom
 //W# ncpile_create
@@ -13,6 +13,9 @@
 //W  ncpile_render
 //W  ncpile_top
 //W  ncplane_above
+//W  ncplane_abs_x
+//W  ncplane_abs_y
+//W  ncplane_abs_yx
 //W  ncplane_at_cursor
 //W  ncplane_at_cursor_cell
 //W  ncplane_at_yx
@@ -30,6 +33,7 @@
 //W# ncplane_dim_yx
 //W  ncplane_dup
 //W# ncplane_erase
+//   ncplane_erase_region
 //W  ncplane_fadein
 //W  ncplane_fadein_iteration
 //W  ncplane_fadeout
@@ -37,6 +41,7 @@
 //W  ncplane_format
 //W  ncplane_gradient
 //W  ncplane_greyscale
+//   ncplane_halign
 //W  ncplane_highgradient
 //W  ncplane_highgradient_sized
 //   ncplane_hline_interp
@@ -55,6 +60,7 @@
 //W  ncplane_on_styles
 //W  ncplane_parent
 //W  ncplane_parent_const
+//W  ncplane_pixelgeom
 //   ncplane_polyfill_yx
 //W  ncplane_pulse
 //   ncplane_putchar_stained
@@ -74,11 +80,13 @@
 //W  ncplane_reparent_family
 //W# ncplane_resize
 //W  ncplane_resizecb
-//   ncplane_resize_maximize
+//W  ncplane_resize_marginalize
+//W  ncplane_resize_maximize
 //W  ncplane_resize_realign
-//   ncplane_rgba
+//W  ncplane_rgba
 //W  ncplane_rotate_ccw
 //W  ncplane_rotate_cw
+//W  ncplane_scrolling_p
 //W  ncplane_set_base
 //W  ncplane_set_base_cell
 //W# ncplane_set_bchannel
@@ -108,22 +116,22 @@
 //W  ncplane_translate
 //W  ncplane_translate_abs
 //   ncplane_userptr
+//   ncplane_valign
 //   ncplane_vline_interp
-//   ncplane_vprintf_aligned
-//   ncplane_vprintf_stained
-//   ncplane_vprintf_yx
+// X ncplane_vprintf_aligned
+// X ncplane_vprintf_stained
+// X ncplane_vprintf_yx
 //W  ncplane_x
 //W  ncplane_y
 //W  ncplane_yx
 //
-// functions manually reimplemented: 39
+// functions manually reimplemented: 40
 // ------------------------------------------
 // (X) wont:  9
-// (+) done: 32 / 0
-// (W) wrap: 24
+// (+) done: 33 / 0
+// (W) wrap: 25
 // (#) test:  5
 // ------------------------------------------
-//W+ ncplane_align
 //W+ ncplane_bchannel
 //W+ ncplane_bg_alpha
 //W# ncplane_bg_default_p
@@ -140,7 +148,9 @@
 //W+ ncplane_fg_rgb
 //W+ ncplane_fg_rgb8
 //W+ ncplane_gradient_sized
+//W+ ncplane_halign
 // + ncplane_hline
+//W  ncplane_moverel
 //W+ ncplane_perimeter
 //W+ ncplane_perimeter_double
 //W+ ncplane_perimeter_rounded
@@ -161,10 +171,9 @@
 //W# ncplane_resize_simple
 // + ncplane_rounded_box
 // + ncplane_rounded_box_sized
+//W+ ncplane_halign
 // + ncplane_vline
-// + ncplane_vprintf
-//
-// NOTE: TODO: Still remains all the ncplane_printf* functions/macros (at the end)
+// X ncplane_vprintf
 
 #[cfg(test)]
 mod test;
@@ -187,36 +196,63 @@ pub use reimplemented::*;
 /// `type in C: ncplane (struct)`
 ///
 ///
-/// # Piles
+/// # About planes and piles
 ///
-/// A single notcurses context is made up of one or more piles.
+/// A given notcurses context is made up of one or more piles.
 ///
-/// A pile is a set of one or more ncplanes, including the partial orderings
-/// made up of their binding and z-axis pointers.
+/// A pile is made up of [`NcPlane`]s, totally ordered on a z-axis.
 ///
-/// A pile has a top and bottom ncplane (this might be a single plane),
-/// and one or more root planes (planes which are bound to themselves).
+/// You can't manage the piles directly, but only the `NcPlanes`.
 ///
-/// Multiple threads can concurrently operate on distinct piles, even changing
-/// one while rendering another.
+/// A pile is destroyed when all its planes are destroyed or moved to other
+/// piles.
 ///
-/// Each plane is part of one and only one pile. By default, a plane is part of
-/// the same pile containing that plane to which it is bound.
+/// A pile has a top and bottom plane (this might be a single `NcPlane`),
+/// and one or more root planes (`NcPlane`s which are bound to themselves).
 ///
-/// If ncpile_create is used in the place of ncplane_create, the returned plane
-/// becomes the root plane, top, and bottom of a new pile.  As a root plane,
+/// Multiple threads can concurrently operate on distinct piles, rendering or
+/// mutating it, while another thread concurrently renders or mutates another.
+///
+/// Each `NcPlane` is part of one and only one pile. By default, an `NcPlane` is
+/// part of the same pile that contains the `NcPlane` to which it is bound.
+///
+/// When an `NcPlane` is created without being bound to another `NcPlane`, then
+/// it becomes the root plane, top, and bottom of a new pile. As a root plane,
 /// it is bound to itself.
 ///
-/// A new pile can also be created by reparenting a plane to itself,
+/// A new pile can also be created by reparenting an `NcPlane` to itself,
 /// though if the plane is already a root plane, this is a no-op.
 ///
-/// When a plane is moved to a different pile (whether new or preexisting),
-/// any planes which were bound to it are rebound to its previous parent.
-/// If the plane was a root plane of some pile, any bound planes become root
-/// planes. The new plane is placed immediately atop its new parent on its new
-/// pile's z-axis. When ncplane_reparent_family() is used, all planes bound to
-/// the reparented plane are moved along with it. Their relative z-order is maintained.
+/// When an `NcPlane` is moved to a different pile (whether new or preexisting),
+/// any `NcPlane`s which were bound to it are rebound to its previous parent.
+/// If the `NcPlane` was a root plane of some pile, any bound planes become root
+/// planes. The new `NcPlane` is placed immediately atop its new parent on its
+/// new pile's z-axis.
 ///
+/// When [`NcPlane::reparent_family`][NcPlane#method.reparent_family] is used,
+/// all `NcPlanes` bound to the reparented `NcPlane` are moved along with it.
+/// Their relative z-order is maintained.
+//
+/// Rendering reduces a pile of `NcPlane`s to a single `NcPlane`, proceeding
+/// from the top to the bottom along a pile's z-axis. The result is a matrix of
+/// [`NcCell`][crate::NcCell]s. Rasterizing takes this matrix, together with the
+/// current state of the visual area, and produces a stream of optimized control
+/// sequences and `EGC`s for the terminal. By writing this stream to the
+/// terminal, the physical display is synced to some pile's `NcPlane`s.
+///
+/// [`NcPlane.render`][crate::NcPlane#method.render] performs the first of these
+/// tasks for the pile of which the plane is a part. The output is maintained
+/// internally; calling `render` again on the same pile will replace this state
+/// with a fresh render. Multiple piles can be concurrently rendered.
+/// [`NcPlane.rasterize`][crate::NcPlane#method.rasterize] performs
+/// rasterization, and writes the result to the terminal. It is a blocking call,
+/// and only one rasterization operation may proceed at a time.
+///
+/// It is necessary to call `NcPlane.rasterize` to generate any visible output;
+/// the various *output calls* only draw to the virtual `NcPlane`s. Most of the
+/// notcurses `statistics` are updated as a result of a render, and screen
+/// geometry is refreshed (similarly to
+/// [`Notcurses.refresh`][crate::Notcurses#method.refresh]) following the render.
 ///
 /// # Methods & Associated Functions
 ///
@@ -224,10 +260,10 @@ pub use reimplemented::*;
 ///
 /// Methods:
 /// - [`NcAlphaBits`](#ncplane-methods-ncalphabits)
-/// - [`NcChannel` & `NcChannelPair`](#ncplane-methods-ncchannel)
-/// - [`NcColor`, `NcRgb` & default color](#ncplane-methods-nccolor-ncrgb--default-color)
-/// - [`NcStyleMask` & `NcPaletteIndex`](#ncplane-methods-ncstylemask--paletteindex)
-/// - [`NcCell` & `NcEgc`](#ncplane-methods-nccell--ncegc)
+/// - [`NcChannel` & `NcChannels`](#ncplane-methods-ncchannel)
+/// - [`NcComponent`, `NcRgb` & default color](#ncplane-methods-nccomponent-ncrgb--default-color)
+/// - [`NcStyle` & `NcPaletteIndex`](#ncplane-methods-ncstylemask--paletteindex)
+/// - [`NcCell` & strings](#ncplane-methods-nccell--strings)
 /// - [cursor](#ncplane-methods-cursor)
 /// - [`NcPlane` & `Notcurses`](#ncplane-methods-ncplane--notcurses)
 /// - [boxes & perimeters](#ncplane-methods-boxes--perimeters)
@@ -239,9 +275,22 @@ pub type NcPlane = crate::bindings::ffi::ncplane;
 /// Options struct for [`NcPlane`]
 pub type NcPlaneOptions = crate::bindings::ffi::ncplane_options;
 
-/// Horizontal alignment relative to the parent plane. Set alignment in 'x'.
+/// Horizontal alignment relative to the parent plane. Use NcAlign for 'x'.
 pub const NCPLANE_OPTION_HORALIGNED: u64 = crate::bindings::ffi::NCPLANE_OPTION_HORALIGNED as u64;
 
+/// Vertical alignment relative to the parent plane. Use NcAlign for 'y'.
+pub const NCPLANE_OPTION_VERALIGNED: u64 = crate::bindings::ffi::NCPLANE_OPTION_VERALIGNED as u64;
+
+/// Maximize relative to the parent plane, modulo the provided margins.
+///
+/// The margins are best-effort; the plane will always be at least 1 column by
+/// 1 row. If the margins can be effected, the plane will be sized to all
+/// remaining space. 'y' and 'x' are overloaded as the top and left margins
+/// when this flag is used. 'rows' and 'cols' must be 0 when this flag is
+/// used. This flag is exclusive with both of the alignment flags.
+pub const NCPLANE_OPTION_MARGINALIZED: u64 =
+    crate::bindings::ffi::NCPLANE_OPTION_MARGINALIZED as u64;
+
 /// I/O wrapper to dump file descriptor to [`NcPlane`]
 ///
 /// `type in C: ncfdplane (struct)`
@@ -251,57 +300,3 @@ pub type NcFdPlane = crate::bindings::ffi::ncfdplane;
 ///
 /// `type in C: ncplane_options (struct)`
 pub type NcFdPlaneOptions = crate::bindings::ffi::ncfdplane_options;
-
-/// Blitter Mode (`NCBLIT_*`)
-///
-/// We never blit full blocks, but instead spaces (more efficient) with the
-/// background set to the desired foreground.
-///
-/// ## Modes
-///
-/// - [`NCBLIT_1x1`]
-/// - [`NCBLIT_2x1`]
-/// - [`NCBLIT_2x2`]
-/// - [`NCBLIT_3x2`]
-/// - [`NCBLIT_4x1`]
-/// - [`NCBLIT_8x1`]
-/// - [`NCBLIT_BRAILLE`]
-/// - [`NCBLIT_DEFAULT`]
-/// - [`NCBLIT_PIXEL`]
-///
-pub type NcBlitter = crate::bindings::ffi::ncblitter_e;
-
-/// [`NcBlitter`] mode using: space, compatible with ASCII
-pub const NCBLIT_1x1: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_1x1;
-
-/// [`NcBlitter`] mode using: halves + 1x1 (space)
-/// ▄▀
-pub const NCBLIT_2x1: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_2x1;
-
-/// [`NcBlitter`] mode using: quadrants + 2x1
-/// ▗▐ ▖▀▟▌▙
-pub const NCBLIT_2x2: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_2x2;
-
-/// [`NcBlitter`] mode using: sextants
-/// 🬀🬁🬂🬃🬄🬅🬆🬇🬈🬉🬊🬋🬌🬍🬎🬏🬐🬑🬒🬓🬔🬕🬖🬗🬘🬙🬚🬛🬜🬝🬞🬟🬠🬡🬢🬣🬤🬥🬦🬧🬨🬩🬪🬫🬬🬭🬮🬯🬰🬱🬲🬳🬴🬵🬶🬷🬸🬹🬺🬻
-pub const NCBLIT_3x2: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_3x2;
-
-/// [`NcBlitter`] mode using: four vertical levels
-/// █▆▄▂
-pub const NCBLIT_4x1: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_4x1;
-
-/// [`NcBlitter`] mode using: eight vertical levels
-/// █▇▆▅▄▃▂▁
-pub const NCBLIT_8x1: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_8x1;
-
-/// [`NcBlitter`] mode using: 4 rows, 2 cols (braille)
-/// ⡀⡄⡆⡇⢀⣀⣄⣆⣇⢠⣠⣤⣦⣧⢰⣰⣴⣶⣷⢸⣸⣼⣾⣿
-pub const NCBLIT_BRAILLE: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_BRAILLE;
-
-/// [`NcBlitter`] mode where the blitter is automatically chosen
-pub const NCBLIT_DEFAULT: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_DEFAULT;
-
-/// [`NcBlitter`] mode (not yet implemented)
-///
-/// See [Sixel in Wikipedia](https://en.wikipedia.org/wiki/Sixel).
-pub const NCBLIT_PIXEL: NcBlitter = crate::bindings::ffi::ncblitter_e_NCBLIT_PIXEL;
