@@ -8,6 +8,7 @@
 #include <unistd.h>
 #include <getopt.h>
 #include <stdlib.h>
+#include <inttypes.h>
 #include <stdatomic.h>
 #include <notcurses/direct.h>
 #include "demo.h"
@@ -20,7 +21,7 @@ static int democount;
 static demoresult* results;
 static char *datadir = NOTCURSES_SHARE;
 
-static const char DEFAULT_DEMO[] = "ixezcytnhdmbkgarwuvlsfjqo";
+static const char DEFAULT_DEMO[] = "ixetunchmdbkywgarvlsfjqzo";
 
 atomic_bool interrupted = ATOMIC_VAR_INIT(false);
 // checked following demos, whether aborted, failed, or otherwise
@@ -79,7 +80,7 @@ static struct {
   { "chunli", chunli_demo, true, },
   { "dragon", dragon_demo, false, },
   { "eagle", eagle_demo, true, },
-  { "fallin'", fallin_demo, false, },
+  { "fission", fission_demo, false, },
   { "grid", grid_demo, false, },
   { "highcon", highcontrast_demo, false, },
   { "intro", intro, false, },
@@ -130,7 +131,7 @@ usage(const char* exe, int status){
   fprintf(out, "usage: ");
   if(n) ncdirect_set_fg_rgb8(n, 0x80, 0xff, 0x80);
   fprintf(out, "%s ", exe);
-  const char* options[] = { "-hVikc", "-m margins", "-p path", "-l loglevel",
+  const char* options[] = { "-hVkc", "-m margins", "-p path", "-l loglevel",
                             "-d mult", "-J jsonfile", "-f renderfile", "demospec",
                             NULL };
   for(const char** op = options ; *op ; ++op){
@@ -141,7 +142,6 @@ usage(const char* exe, int status){
   const char* optexpo[] = {
     "-h|--help", "this message",
     "-V|--version", "print program name and version",
-    "-i", "ignore failures, keep going",
     "-k", "keep screen; do not switch to alternate",
     "-d", "delay multiplier (non-negative float)",
     "-J", "emit JSON summary to file",
@@ -190,7 +190,7 @@ usage(const char* exe, int status){
 }
 
 static int
-ext_demos(struct notcurses* nc, const char* spec, bool ignore_failures){
+ext_demos(struct notcurses* nc, const char* spec){
   int ret = 0;
   results = malloc(sizeof(*results) * strlen(spec));
   if(results == NULL){
@@ -218,11 +218,8 @@ ext_demos(struct notcurses* nc, const char* spec, bool ignore_failures){
     // set the standard plane's base character to an opaque black, but don't
     // erase the plane (we let one demo bleed through to the next, an effect
     // we exploit in a few transitions).
-    nccell c = CELL_TRIVIAL_INITIALIZER;
-    cell_set_fg_rgb8(&c, 0, 0, 0);
-    cell_set_bg_rgb8(&c, 0, 0, 0);
-    ncplane_set_base_cell(n, &c);
-    cell_release(n, &c);
+    uint64_t stdc = NCCHANNELS_INITIALIZER(0, 0, 0, 0, 0, 0);
+    ncplane_set_base(n, "", 0, stdc);
 
     hud_schedule(demos[idx].name);
     ret = demos[idx].fxn(nc);
@@ -233,7 +230,7 @@ ext_demos(struct notcurses* nc, const char* spec, bool ignore_failures){
     prevns = nowns;
     results[i].result = ret;
     hud_completion_notify(&results[i]);
-    if(ret && !ignore_failures){
+    if(ret){
       break;
     }
   }
@@ -244,21 +241,18 @@ ext_demos(struct notcurses* nc, const char* spec, bool ignore_failures){
 // specification, also returns NULL, heh. determine this by argv[optind];
 // if it's NULL, there were valid options, but no spec.
 static const char*
-handle_opts(int argc, char** argv, notcurses_options* opts,
-            bool* ignore_failures, FILE** json_output){
+handle_opts(int argc, char** argv, notcurses_options* opts, FILE** json_output){
   bool constant_seed = false;
-  *ignore_failures = false;
   char *renderfile = NULL;
   *json_output = NULL;
   int c;
-  memset(opts, 0, sizeof(*opts));
   const struct option longopts[] = {
     { .name = "help", .has_arg = 0, .flag = NULL, .val = 'h', },
     { .name = "version", .has_arg = 0, .flag = NULL, .val = 'V', },
     { .name = NULL, .has_arg = 0, .flag = NULL, .val = 0, },
   };
   int lidx;
-  while((c = getopt_long(argc, argv, "VhickJ:l:r:d:f:p:m:", longopts, &lidx)) != EOF){
+  while((c = getopt_long(argc, argv, "VhckJ:l:r:d:f:p:m:", longopts, &lidx)) != EOF){
     switch(c){
       case 'h':
         usage(*argv, EXIT_SUCCESS);
@@ -300,9 +294,6 @@ handle_opts(int argc, char** argv, notcurses_options* opts,
       case 'c':
         constant_seed = true;
         break;
-      case 'i':
-        *ignore_failures = true;
-        break;
       case 'k':
         opts->flags |= NCOPTION_NO_ALTERNATE_SCREEN;
         break;
@@ -393,7 +384,7 @@ summary_json(FILE* f, const char* spec, int rows, int cols){
     if(results[i].result || !results[i].stats.renders){
       continue;
     }
-    ret |= (fprintf(f, "\"%s\":{\"bytes\":\"%ju\",\"frames\":\"%ju\",\"ns\":\"%ju\"}%s",
+    ret |= (fprintf(f, "\"%s\":{\"bytes\":\"%"PRIu64"\",\"frames\":\"%"PRIu64"\",\"ns\":\"%"PRIu64"\"}%s",
                     demos[results[i].selector - 'a'].name, results[i].stats.render_bytes,
                     results[i].stats.renders, results[i].timens, i < strlen(spec) - 1 ? "," : "") < 0);
   }
@@ -425,9 +416,9 @@ summary_table(struct ncdirect* nc, const char* spec, bool canimage, bool canvide
     nsdelta += results[i].timens;
     qprefix(results[i].timens, NANOSECS_IN_SEC, timebuf, 0);
     bprefix(results[i].stats.render_bytes, 1, totalbuf, 0);
-    if(results[i].stats.renders){
-      qprefix((uintmax_t)results[i].stats.writeouts * NANOSECS_IN_SEC * 1000 /
-              (results[i].stats.render_ns + results[i].stats.writeout_ns + results[i].stats.raster_ns),
+    uint64_t divisor = results[i].stats.render_ns + results[i].stats.writeout_ns + results[i].stats.raster_ns;
+    if(divisor){
+      qprefix((uintmax_t)results[i].stats.writeouts * NANOSECS_IN_SEC * 1000 / divisor,
               1000, tfpsbuf, 0);
     }else{
       qprefix(0, NANOSECS_IN_SEC, tfpsbuf, 0);
@@ -504,8 +495,8 @@ static int
 scrub_stdplane(struct notcurses* nc){
   struct ncplane* n = notcurses_stdplane(nc);
   uint64_t channels = 0;
-  channels_set_fg_rgb(&channels, 0); // explicit black + opaque
-  channels_set_bg_rgb(&channels, 0);
+  ncchannels_set_fg_rgb(&channels, 0); // explicit black + opaque
+  ncchannels_set_bg_rgb(&channels, 0);
   if(ncplane_set_base(n, "", 0, channels)){
     return -1;
   }
@@ -518,12 +509,11 @@ int main(int argc, char** argv){
   // ensure SIGWINCH is delivered only to a thread doing input
   sigemptyset(&sigmask);
   sigaddset(&sigmask, SIGWINCH);
-  pthread_sigmask(SIG_SETMASK, &sigmask, NULL);
+  pthread_sigmask(SIG_BLOCK, &sigmask, NULL);
   const char* spec;
   FILE* json = NULL; // emit JSON summary to this file? (-J)
-  bool ignore_failures; // continue after a failure? (-k)
-  notcurses_options nopts;
-  if((spec = handle_opts(argc, argv, &nopts, &ignore_failures, &json)) == NULL){
+  notcurses_options nopts = {};
+  if((spec = handle_opts(argc, argv, &nopts, &json)) == NULL){
     if(argv[optind] != NULL){
       usage(*argv, EXIT_FAILURE);
     }
@@ -543,16 +533,14 @@ int main(int argc, char** argv){
   if((nc = notcurses_init(&nopts, NULL)) == NULL){
     return EXIT_FAILURE;
   }
+  notcurses_mouse_enable(nc);
   const bool canimage = notcurses_canopen_images(nc);
   const bool canvideo = notcurses_canopen_videos(nc);
-  if(notcurses_mouse_enable(nc)){
-    goto err;
-  }
+  int dimx, dimy;
+  ncplane_dim_yx(notcurses_stdplane(nc), &dimy, &dimx);
   if(input_dispatcher(nc)){
     goto err;
   }
-  int dimx, dimy;
-  notcurses_term_dim_yx(nc, &dimy, &dimx);
   if(dimy < MIN_SUPPORTED_ROWS || dimx < MIN_SUPPORTED_COLS){
     goto err;
   }
@@ -584,7 +572,7 @@ int main(int argc, char** argv){
       goto err;
     }
     notcurses_stats_reset(nc, NULL);
-    if(ext_demos(nc, spec, ignore_failures)){
+    if(ext_demos(nc, spec)){
       goto err;
     }
     if(hud_destroy()){ // destroy here since notcurses_drop_planes will kill it
@@ -593,12 +581,10 @@ int main(int argc, char** argv){
     if(fpsgraph_stop()){
       goto err;
     }
-    about_destroy(nc);
+    about_destroy(nc); // also kills debug window
   }while(restart_demos);
   ncmenu_destroy(menu);
-  if(stop_input()){
-    goto err;
-  }
+  stop_input();
   if(notcurses_stop(nc)){
     return EXIT_FAILURE;
   }
@@ -624,10 +610,11 @@ int main(int argc, char** argv){
   return EXIT_SUCCESS;
 
 err:
+  stop_input();
   notcurses_term_dim_yx(nc, &dimy, &dimx);
   notcurses_stop(nc);
   if(dimy < MIN_SUPPORTED_ROWS || dimx < MIN_SUPPORTED_COLS){
-    fprintf(stderr, "At least an %dx%d terminal is required (current: %dx%d)\n",
+    fprintf(stderr, "At least a %dx%d terminal is required (current: %dx%d)\n",
             MIN_SUPPORTED_COLS, MIN_SUPPORTED_ROWS, dimx, dimy);
   }
   return EXIT_FAILURE;
