@@ -36,15 +36,17 @@ zoom_map(struct notcurses* nc, const char* map, int* ret){
   if(ncv == NULL){
     return NULL;
   }
-  int vheight, yscale;
-  int vwidth, xscale;
+  // true height and width of visual, and blitter scaling parameters
+  int vheight, yscale, vwidth, xscale;
   // first we want to get the true size, so don't supply NCSSCALE_STRETCH yet,
   // but *do* explicitly supply NCBLIT_2x2 since we're not scaling.
   struct ncvisual_options vopts = {
     .y = 1,
     .blitter = NCBLIT_2x2,
+    .flags = NCVISUAL_OPTION_NOINTERPOLATE,
   };
-  if(ncvisual_geom(nc, ncv, &vopts, &vheight, &vwidth, &yscale, &xscale)){
+  if(ncvisual_blitter_geom(nc, ncv, &vopts, &vheight, &vwidth,
+                           &yscale, &xscale, NULL)){
     ncvisual_destroy(ncv);
     return NULL;
   }
@@ -115,10 +117,10 @@ zoom_map(struct notcurses* nc, const char* map, int* ret){
 static int
 draw_eagle(struct ncplane* n, const char* sprite){
   nccell bgc = CELL_TRIVIAL_INITIALIZER;
-  cell_set_fg_alpha(&bgc, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&bgc, CELL_ALPHA_TRANSPARENT);
+  nccell_set_fg_alpha(&bgc, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&bgc, NCALPHA_TRANSPARENT);
   ncplane_set_base_cell(n, &bgc);
-  cell_release(n, &bgc);
+  nccell_release(n, &bgc);
   size_t s;
   int sbytes;
   for(s = 0 ; sprite[s] ; ++s){
@@ -166,7 +168,7 @@ eagles(struct notcurses* nc, struct ncplane* n){
   } e[3];
   for(size_t i = 0 ; i < sizeof(e) / sizeof(*e) ; ++i){
     e[i].xoff = 0;
-    e[i].yoff = random() % ((truey - height) / 2);
+    e[i].yoff = rand() % ((truey - height) / 2);
     struct ncplane_options nopts = {
       .y = e[i].yoff,
       .x = e[i].xoff,
@@ -191,14 +193,14 @@ eagles(struct notcurses* nc, struct ncplane* n){
       if(e[i].xoff >= truex){
         continue;
       }
-      e[i].yoff += random() % (2 + i) - 1;
+      e[i].yoff += rand() % (2 + i) - 1;
       if(e[i].yoff < 0){
         e[i].yoff = 0;
       }else if(e[i].yoff + height >= truey){
         e[i].yoff = truey - height - 1;
       }
       int scale = truex >= 80 ? truex / 80 : 1;
-      e[i].xoff += (random() % scale) + 1;
+      e[i].xoff += (rand() % scale) + 1;
       ncplane_move_yx(e[i].n, e[i].yoff, e[i].xoff);
       ++eaglesmoved;
     }
