@@ -1,5 +1,6 @@
 #include "demo.h"
 #include <pthread.h>
+#include <inttypes.h>
 
 // we provide a heads-up display throughout the demo, detailing the demos we're
 // about to run, running, and just runned. the user can move this HUD with
@@ -28,6 +29,8 @@ static int plot_pos_y;
 
 #define FPSHZ 2
 
+#define FPSGRAPH_MAX_COLS 72 // give it some room on each side of an 80-column term
+
 // how many columns for runtime?
 #define HUD_ROWS (3 + 2) // 2 for borders
 static const int HUD_COLS = 23 + 2; // 2 for borders
@@ -54,10 +57,10 @@ static struct ncplane* debug; // "debug info" modal popup
 static int
 hud_standard_bg_rgb(struct ncplane* n){
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb8(&channels, 0x80, 0x80, 0x80);
-  channels_set_bg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_bg_rgb8(&channels, 0x80, 0x80, 0x80);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb8(&channels, 0x80, 0x80, 0x80);
+  ncchannels_set_bg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_bg_rgb8(&channels, 0x80, 0x80, 0x80);
   if(ncplane_set_base(n, "", 0, channels) >= 0){
     return -1;
   }
@@ -99,9 +102,12 @@ debug_toggle(struct notcurses* nc){
     .y = 3,
     .x = NCALIGN_CENTER,
     .rows = count_debug_lines(output, outputlen) + 1,
-    // 1 plus the max len of debug output so it can print against right border
+    // make it one column longer than the maximum debug output, so that a full
+    // line of output doesn't cause trigger a newline. we'll make the last
+    // column transparent.
     .cols = 81,
-    .flags = NCPLANE_OPTION_HORALIGNED,
+    .flags = NCPLANE_OPTION_HORALIGNED | NCPLANE_OPTION_FIXED,
+    .name = "dbg",
   };
   struct ncplane* n = ncplane_create(notcurses_stdplane(nc), &nopts);
   if(n == NULL){
@@ -109,8 +115,8 @@ debug_toggle(struct notcurses* nc){
     return;
   }
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_TRANSPARENT);
-  channels_set_bg_rgb(&channels, 0xffffe5);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_TRANSPARENT);
+  ncchannels_set_bg_rgb(&channels, 0xffffe5);
   ncplane_set_base(n, " ", 0, channels);
   ncplane_set_scrolling(n, true);
   ncplane_set_fg_rgb(n, 0x0a0a0a);
@@ -120,6 +126,13 @@ debug_toggle(struct notcurses* nc){
     ncplane_destroy(n);
     return;
   }
+  for(int y = 0 ; y < ncplane_dim_y(n) ; ++y){
+    nccell c = CELL_TRIVIAL_INITIALIZER;
+    nccell_set_fg_alpha(&c, NCALPHA_TRANSPARENT);
+    nccell_set_bg_alpha(&c, NCALPHA_TRANSPARENT);
+    ncplane_putc_yx(n, y, ncplane_dim_x(n) - 1, &c);
+    nccell_release(n, &c);
+  }
   ncplane_putstr_aligned(n, ncplane_dim_y(n) - 1, NCALIGN_CENTER, "Press Alt+d to hide this window");
   free(output);
   debug = n;
@@ -142,19 +155,19 @@ about_toggle(struct notcurses* nc){
     .x = NCALIGN_CENTER,
     .rows = ABOUT_ROWS,
     .cols = ABOUT_COLS,
-    .flags = NCPLANE_OPTION_HORALIGNED,
+    .flags = NCPLANE_OPTION_HORALIGNED | NCPLANE_OPTION_FIXED,
   };
   struct ncplane* n = ncplane_create(notcurses_stdplane(nc), &nopts);
   // let the glyphs below show through, but only dimly
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb8(&channels, 0x0, 0x0, 0x0);
-  channels_set_bg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_bg_rgb8(&channels, 0x0, 0x0, 0x0);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb8(&channels, 0x0, 0x0, 0x0);
+  ncchannels_set_bg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_bg_rgb8(&channels, 0x0, 0x0, 0x0);
   if(ncplane_set_base(n, "", 0, channels) >= 0){
     ncplane_set_fg_rgb(n, 0x11ffff);
     ncplane_set_bg_rgb(n, 0);
-    ncplane_set_bg_alpha(n, CELL_ALPHA_BLEND);
+    ncplane_set_bg_alpha(n, NCALPHA_BLEND);
     ncplane_printf_aligned(n, 1, NCALIGN_CENTER, "notcurses-demo %s", notcurses_version());
     ncplane_printf_aligned(n, 3, NCALIGN_LEFT, "  P toggle plot");
     ncplane_printf_aligned(n, 3, NCALIGN_RIGHT, "toggle help Ctrl+U  ");
@@ -166,26 +179,30 @@ about_toggle(struct notcurses* nc){
     nccell lr = CELL_TRIVIAL_INITIALIZER, ll = CELL_TRIVIAL_INITIALIZER;
     nccell hl = CELL_TRIVIAL_INITIALIZER, vl = CELL_TRIVIAL_INITIALIZER;
     channels = 0;
-    channels_set_fg_rgb(&channels, 0xc020c0);
-    channels_set_bg_rgb(&channels, 0);
-    if(cells_rounded_box(n, NCSTYLE_NONE, channels, &ul, &ur, &ll, &lr, &hl, &vl) == 0){
+    ncchannels_set_fg_rgb(&channels, 0xc020c0);
+    ncchannels_set_bg_rgb(&channels, 0);
+    if(nccells_rounded_box(n, NCSTYLE_NONE, channels, &ul, &ur, &ll, &lr, &hl, &vl) == 0){
       if(ncplane_perimeter(n, &ul, &ur, &ll, &lr, &hl, &vl, 0) == 0){
-        cell_release(n, &ul); cell_release(n, &ur); cell_release(n, &hl);
-        cell_release(n, &ll); cell_release(n, &lr); cell_release(n, &vl);
+        nccell_release(n, &ul); nccell_release(n, &ur); nccell_release(n, &hl);
+        nccell_release(n, &ll); nccell_release(n, &lr); nccell_release(n, &vl);
         about = n;
         return;
       }
-      cell_release(n, &ul); cell_release(n, &ur); cell_release(n, &hl);
-      cell_release(n, &ll); cell_release(n, &lr); cell_release(n, &vl);
+      nccell_release(n, &ul); nccell_release(n, &ur); nccell_release(n, &hl);
+      nccell_release(n, &ll); nccell_release(n, &lr); nccell_release(n, &vl);
     }
   }
   ncplane_destroy(n);
 }
 
+// kills about window *and* debug window
 void about_destroy(struct notcurses* nc){
   if(about){
     about_toggle(nc);
   }
+  if(debug){
+    debug_toggle(nc);
+  }
 }
 
 static void
@@ -196,8 +213,9 @@ hud_toggle(struct notcurses* nc){
   }
   hud_hidden = !hud_hidden;
   if(hud_hidden){
-    ncplane_move_bottom(hud);
+    ncplane_reparent(hud, hud);
   }else{
+    ncplane_reparent(hud, notcurses_stdplane(nc));
     ncplane_move_top(hud);
   }
   demo_render(nc);
@@ -211,8 +229,9 @@ fpsplot_toggle(struct notcurses* nc){
   }
   plot_hidden = !plot_hidden;
   if(plot_hidden){
-    ncplane_move_bottom(ncuplot_plane(plot));
+    ncplane_reparent(ncuplot_plane(plot), ncuplot_plane(plot));
   }else{
+    ncplane_reparent(ncuplot_plane(plot), notcurses_stdplane(nc));
     ncplane_move_top(ncuplot_plane(plot));
   }
   return demo_render(nc);
@@ -298,13 +317,13 @@ struct ncmenu* menu_create(struct notcurses* nc){
   };
   uint64_t headerchannels = 0;
   uint64_t sectionchannels = 0;
-  channels_set_fg_rgb(&sectionchannels, 0xffffff);
-  channels_set_bg_rgb(&sectionchannels, 0x000000);
-  channels_set_fg_alpha(&sectionchannels, CELL_ALPHA_HIGHCONTRAST);
-  channels_set_bg_alpha(&sectionchannels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb(&headerchannels, 0xffffff);
-  channels_set_bg_rgb(&headerchannels, 0x7f347f);
-  channels_set_bg_alpha(&headerchannels, CELL_ALPHA_BLEND);
+  ncchannels_set_fg_rgb(&sectionchannels, 0xffffff);
+  ncchannels_set_bg_rgb(&sectionchannels, 0x000000);
+  ncchannels_set_fg_alpha(&sectionchannels, NCALPHA_HIGHCONTRAST);
+  ncchannels_set_bg_alpha(&sectionchannels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb(&headerchannels, 0xffffff);
+  ncchannels_set_bg_rgb(&headerchannels, 0x7f347f);
+  ncchannels_set_bg_alpha(&headerchannels, NCALPHA_BLEND);
   const ncmenu_options mopts = {
     .sections = sections,
     .sectioncount = sizeof(sections) / sizeof(*sections),
@@ -322,28 +341,28 @@ hud_refresh(struct ncplane* n){
   nccell ul = CELL_TRIVIAL_INITIALIZER, ur = CELL_TRIVIAL_INITIALIZER;
   nccell lr = CELL_TRIVIAL_INITIALIZER, ll = CELL_TRIVIAL_INITIALIZER;
   nccell hl = CELL_TRIVIAL_INITIALIZER, vl = CELL_TRIVIAL_INITIALIZER;
-  if(cells_rounded_box(n, NCSTYLE_NONE, 0, &ul, &ur, &ll, &lr, &hl, &vl)){
+  if(nccells_rounded_box(n, NCSTYLE_NONE, 0, &ul, &ur, &ll, &lr, &hl, &vl)){
     return -1;
   }
-  ul.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  ur.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  ll.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  lr.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  hl.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  vl.channels = CHANNELS_RGB_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
-  cell_set_bg_alpha(&ul, CELL_ALPHA_BLEND);
-  cell_set_bg_alpha(&ur, CELL_ALPHA_BLEND);
-  cell_set_bg_alpha(&ll, CELL_ALPHA_BLEND);
-  cell_set_bg_alpha(&lr, CELL_ALPHA_BLEND);
-  cell_set_bg_alpha(&hl, CELL_ALPHA_BLEND);
-  cell_set_bg_alpha(&vl, CELL_ALPHA_BLEND);
+  ul.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  ur.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  ll.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  lr.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  hl.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  vl.channels = NCCHANNELS_INITIALIZER(0xf0, 0xc0, 0xc0, 0, 0, 0);
+  nccell_set_bg_alpha(&ul, NCALPHA_BLEND);
+  nccell_set_bg_alpha(&ur, NCALPHA_BLEND);
+  nccell_set_bg_alpha(&ll, NCALPHA_BLEND);
+  nccell_set_bg_alpha(&lr, NCALPHA_BLEND);
+  nccell_set_bg_alpha(&hl, NCALPHA_BLEND);
+  nccell_set_bg_alpha(&vl, NCALPHA_BLEND);
   if(ncplane_perimeter(n, &ul, &ur, &ll, &lr, &hl, &vl, 0)){
-    cell_release(n, &ul); cell_release(n, &ur); cell_release(n, &hl);
-    cell_release(n, &ll); cell_release(n, &lr); cell_release(n, &vl);
+    nccell_release(n, &ul); nccell_release(n, &ur); nccell_release(n, &hl);
+    nccell_release(n, &ll); nccell_release(n, &lr); nccell_release(n, &vl);
     return -1;
   }
-  cell_release(n, &ul); cell_release(n, &ur); cell_release(n, &hl);
-  cell_release(n, &ll); cell_release(n, &lr); cell_release(n, &vl);
+  nccell_release(n, &ul); nccell_release(n, &ur); nccell_release(n, &hl);
+  nccell_release(n, &ll); nccell_release(n, &lr); nccell_release(n, &vl);
   return 0;
 }
 
@@ -366,15 +385,16 @@ hud_print_finished(elem* list){
     if(hud){
       nccell c = CELL_TRIVIAL_INITIALIZER;
       ncplane_base(hud, &c);
-      ncplane_set_bg_rgb(hud, cell_bg_rgb(&c));
-      ncplane_set_bg_alpha(hud, CELL_ALPHA_BLEND);
+      ncplane_set_bg_rgb(hud, nccell_bg_rgb(&c));
+      ncplane_set_bg_alpha(hud, NCALPHA_BLEND);
       ncplane_set_fg_rgb(hud, 0xffffff);
-      ncplane_set_fg_alpha(hud, CELL_ALPHA_OPAQUE);
-      cell_release(hud, &c);
+      ncplane_set_fg_alpha(hud, NCALPHA_OPAQUE);
+      nccell_release(hud, &c);
       if(ncplane_printf_yx(hud, line, 1, "%d", e->frames) < 0){
         return -1;
       }
-      if(ncplane_printf_yx(hud, line, 7, "%ju.%03jus", e->totalns / NANOSECS_IN_SEC,
+      if(ncplane_printf_yx(hud, line, 7, "%"PRIu64".%03"PRIu64"s",
+                           e->totalns / NANOSECS_IN_SEC,
                            (e->totalns % NANOSECS_IN_SEC) / 1000000) < 0){
         return -1;
       }
@@ -393,16 +413,17 @@ struct ncplane* hud_create(struct notcurses* nc){
   }
   int dimx, dimy;
   notcurses_term_dim_yx(nc, &dimy, &dimx);
-  int yoffset = dimy - HUD_ROWS;
   struct ncplane_options nopts = {
-    .y = yoffset,
-    .x = 9,
+    // FPS graph is 6 rows tall; we want one row above it
+    .y = dimy - 6 - HUD_ROWS - 1,
+    .x = NCALIGN_CENTER,
     .rows = HUD_ROWS,
     .cols = HUD_COLS,
     .userptr = NULL,
     .name = "hud",
     .resizecb = NULL,
-    .flags = 0,
+    .flags = NCPLANE_OPTION_HORALIGNED |
+             NCPLANE_OPTION_FIXED,
   };
   struct ncplane* n = ncplane_create(notcurses_stdplane(nc), &nopts);
   if(n == NULL){
@@ -412,9 +433,9 @@ struct ncplane* hud_create(struct notcurses* nc){
   hud_refresh(n);
   ncplane_set_fg_rgb(n, 0xffffff);
   ncplane_set_bg_rgb(n, 0);
-  ncplane_set_bg_alpha(n, CELL_ALPHA_BLEND);
+  ncplane_set_bg_alpha(n, NCALPHA_BLEND);
   if(hud_hidden){
-    ncplane_move_bottom(n);
+    ncplane_reparent(n, n);
   }
   return (hud = n);
 }
@@ -579,16 +600,16 @@ int demo_render(struct notcurses* nc){
     ++elems->frames;
     nccell c = CELL_TRIVIAL_INITIALIZER;
     ncplane_base(hud, &c);
-    ncplane_set_bg_rgb(hud, cell_bg_rgb(&c));
-    ncplane_set_bg_alpha(hud, CELL_ALPHA_BLEND);
+    ncplane_set_bg_rgb(hud, nccell_bg_rgb(&c));
+    ncplane_set_bg_alpha(hud, NCALPHA_BLEND);
     ncplane_set_fg_rgb(hud, 0x80d0ff);
-    ncplane_set_fg_alpha(hud, CELL_ALPHA_OPAQUE);
-    cell_release(hud, &c);
+    ncplane_set_fg_alpha(hud, NCALPHA_OPAQUE);
+    nccell_release(hud, &c);
     ncplane_on_styles(hud, NCSTYLE_BOLD);
     if(ncplane_printf_yx(hud, 1, 1, "%d", elems->frames) < 0){
       return -1;
     }
-    if(ncplane_printf_yx(hud, 1, 7, "%ju.%03jus", ns / NANOSECS_IN_SEC,
+    if(ncplane_printf_yx(hud, 1, 7, "%"PRIu64".%03"PRIu64"s", ns / NANOSECS_IN_SEC,
                          (ns % NANOSECS_IN_SEC) / 1000000) < 0){
       return -1;
     }
@@ -598,7 +619,7 @@ int demo_render(struct notcurses* nc){
     ncplane_off_styles(hud, NCSTYLE_BOLD);
   }
   ncinput ni;
-  char32_t id;
+  uint32_t id;
   id = demo_getc_nblock(nc, &ni);
   int ret = notcurses_render(nc);
   if(ret){
@@ -615,14 +636,15 @@ int fpsgraph_init(struct notcurses* nc){
   int dimy, dimx;
   struct ncplane* stdn = notcurses_stddim_yx(nc, &dimy, &dimx);
   ncplane_options nopts = {
-    .y = dimy - PLOTHEIGHT,
+    .y = NCALIGN_BOTTOM,
     .x = NCALIGN_CENTER,
     .rows = PLOTHEIGHT,
-    .cols = dimx > 80 ? 80 : dimx,
+    .cols = dimx > FPSGRAPH_MAX_COLS ? FPSGRAPH_MAX_COLS : dimx,
     .userptr = NULL,
     .name = "fps",
     .resizecb = ncplane_resize_realign,
-    .flags = NCPLANE_OPTION_HORALIGNED,
+    .flags = NCPLANE_OPTION_HORALIGNED | NCPLANE_OPTION_VERALIGNED
+             | NCPLANE_OPTION_FIXED,
   };
   struct ncplane* newp = ncplane_create(stdn, &nopts);
   if(newp == NULL){
@@ -630,10 +652,10 @@ int fpsgraph_init(struct notcurses* nc){
   }
   uint32_t style = 0;
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb(&channels, 0x201020);
-  channels_set_bg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_bg_rgb(&channels, 0x201020);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb(&channels, 0x201020);
+  ncchannels_set_bg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_bg_rgb(&channels, 0x201020);
   ncplane_set_base(newp, "", style, channels);
   ncplot_options opts;
   memset(&opts, 0, sizeof(opts));
@@ -643,15 +665,15 @@ int fpsgraph_init(struct notcurses* nc){
   opts.gridtype = NCBLIT_BRAILLE;
   opts.legendstyle = NCSTYLE_ITALIC | NCSTYLE_BOLD;
   opts.title = "frames per semisecond";
-  channels_set_fg_rgb8(&opts.minchannels, 0x80, 0x80, 0xff);
-  channels_set_bg_rgb(&opts.minchannels, 0x201020);
-  channels_set_bg_alpha(&opts.minchannels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb8(&opts.maxchannels, 0x80, 0xff, 0x80);
-  channels_set_bg_rgb(&opts.maxchannels, 0x201020);
-  channels_set_bg_alpha(&opts.maxchannels, CELL_ALPHA_BLEND);
+  ncchannels_set_fg_rgb8(&opts.minchannels, 0x80, 0x80, 0xff);
+  ncchannels_set_bg_rgb(&opts.minchannels, 0x201020);
+  ncchannels_set_bg_alpha(&opts.minchannels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb8(&opts.maxchannels, 0x80, 0xff, 0x80);
+  ncchannels_set_bg_rgb(&opts.maxchannels, 0x201020);
+  ncchannels_set_bg_alpha(&opts.maxchannels, NCALPHA_BLEND);
+  // takes ownership of newp on all paths
   struct ncuplot* fpsplot = ncuplot_create(newp, &opts, 0, 0);
   if(!fpsplot){
-    ncplane_destroy(newp);
     return EXIT_FAILURE;
   }
   plot = fpsplot;
@@ -659,7 +681,7 @@ int fpsgraph_init(struct notcurses* nc){
   clock_gettime(CLOCK_MONOTONIC, &ts);
   plottimestart = timespec_to_ns(&ts);
   if(plot_hidden){
-    ncplane_move_bottom(newp);
+    ncplane_reparent(ncuplot_plane(plot), ncuplot_plane(plot));
   }
   return 0;
 }
