@@ -62,20 +62,18 @@ rotate_visual(struct notcurses* nc, struct ncplane* n, int dy, int dx){
     fromx = (dx - dy * 2) / 2;
     dx = dy * 2;
   }
-//fprintf(stderr, "ASK %d/%d @ %d/%d: %p\n", dy, dx, fromy, fromx);
-  struct ncvisual* ncv = ncvisual_from_plane(n, NCBLIT_DEFAULT, fromy, fromx, dy, dx);
-//fprintf(stderr, "%d/%d @ %d/%d: %p\n", dy, dx, fromy, fromx, ncv);
+  struct ncvisual* ncv = ncvisual_from_plane(n, NCBLIT_2x1, fromy, fromx, dy, dx);
   if(!ncv){
     ncvisual_destroy(ncv);
     return -1;
   }
   ncplane_destroy(n);
   int dimy, dimx;
-  n = notcurses_stddim_yx(nc, &dimy, &dimx);
+  struct ncplane* stdn = notcurses_stddim_yx(nc, &dimy, &dimx);
   const int ROTATIONS = 32;
   timespec_div(&demodelay, ROTATIONS / 2, &scaled);
   struct ncvisual_options vopts = { };
-  ncplane_erase(n);
+  ncplane_erase(stdn);
   struct ncvisual* nncv = NULL;
   if(notcurses_canopen_images(nc)){
     char* path = find_data("normal.png");
@@ -83,14 +81,12 @@ rotate_visual(struct notcurses* nc, struct ncplane* n, int dy, int dx){
       nncv = ncvisual_from_file(path);
       if(nncv){
         struct ncvisual_options nvopts = {
-          .n = notcurses_stdplane(nc),
-          .y = 1,
+          .n = stdn,
           .scaling = NCSCALE_STRETCH,
         };
         if(ncvisual_render(nc, nncv, &nvopts) == NULL){
           return -1;
         }
-        ncplane_move_below(notcurses_stdplane(nc), n);
       }
       free(path);
     }
@@ -101,10 +97,9 @@ rotate_visual(struct notcurses* nc, struct ncplane* n, int dy, int dx){
       r = -1;
       break;
     }
-    int vy, vx, vyscale, vxscale;
-    ncvisual_geom(nc, ncv, &vopts, &vy, &vx, &vyscale, &vxscale);
-    vopts.x = (dimx - (vx / vxscale)) / 2;
-    vopts.y = (dimy - (vy / vyscale)) / 2;
+    vopts.x = NCALIGN_CENTER;
+    vopts.y = NCALIGN_CENTER;
+    vopts.flags |= NCVISUAL_OPTION_HORALIGNED | NCVISUAL_OPTION_VERALIGNED;
     struct ncplane* newn;
     if((newn = ncvisual_render(nc, ncv, &vopts)) == NULL){
       r = -1;
@@ -153,21 +148,24 @@ offset(uint32_t* rgba, int y, int x, int dx){
 
 // make a pixel array out from the center, blitting it as we go
 int normal_demo(struct notcurses* nc){
+  if(!notcurses_canutf8(nc)){
+    return 0;
+  }
   int dy, dx;
   int r = -1;
   struct ncplane* nstd = notcurses_stddim_yx(nc, &dy, &dx);
   ncplane_erase(nstd);
   nccell c = CELL_TRIVIAL_INITIALIZER;
-  cell_set_fg_rgb8(&c, 0x0, 0x0, 0x0);
-  cell_set_bg_rgb8(&c, 0x0, 0x0, 0x0);
+  nccell_set_fg_rgb8(&c, 0x0, 0x0, 0x0);
+  nccell_set_bg_rgb8(&c, 0x0, 0x0, 0x0);
   ncplane_set_base_cell(nstd, &c);
-  cell_release(nstd, &c);
+  nccell_release(nstd, &c);
   struct ncplane* n = NULL;
   struct ncvisual_options vopts = {
     .n = nstd,
   };
   int yscale, xscale;
-  ncvisual_geom(nc, NULL, &vopts, NULL, NULL, &yscale, &xscale);
+  ncvisual_blitter_geom(nc, NULL, &vopts, NULL, NULL, &yscale, &xscale, NULL);
   dy *= yscale;
   dx *= xscale;
   uint32_t* rgba = malloc(sizeof(*rgba) * dy * dx);
@@ -225,10 +223,10 @@ int normal_demo(struct notcurses* nc){
   ncplane_home(n);
   uint64_t tl, tr, bl, br;
   tl = tr = bl = br = 0;
-  channels_set_fg_rgb8(&tl, 0, 0, 0);
-  channels_set_fg_rgb8(&tr, 0, 0xff, 0);
-  channels_set_fg_rgb8(&bl, 0xff, 0, 0xff);
-  channels_set_fg_rgb8(&br, 0, 0, 0);
+  ncchannels_set_fg_rgb8(&tl, 0, 0, 0);
+  ncchannels_set_fg_rgb8(&tr, 0, 0xff, 0);
+  ncchannels_set_fg_rgb8(&bl, 0xff, 0, 0xff);
+  ncchannels_set_fg_rgb8(&br, 0, 0, 0);
   ncplane_dim_yx(n, &dy, &dx);
   if(ncplane_stain(n, dy - 1, dx - 1, tl, tr, bl, br) < 0){
     goto err;
@@ -236,10 +234,10 @@ int normal_demo(struct notcurses* nc){
   DEMO_RENDER(nc);
   timespec_div(&demodelay, 2, &scaled);
   demo_nanosleep(nc, &scaled);
-  cell_set_fg_rgb8(&c, 0, 0, 0);
-  cell_set_bg_rgb8(&c, 0, 0, 0);
+  nccell_set_fg_rgb8(&c, 0, 0, 0);
+  nccell_set_bg_rgb8(&c, 0, 0, 0);
   ncplane_set_base_cell(nstd, &c);
-  cell_release(nstd, &c);
+  nccell_release(nstd, &c);
   r = rotate_visual(nc, n, dy, dx);
   return r;
 
