@@ -40,23 +40,23 @@ pbar_make(struct notcurses* nc, int row){
     return NULL;
   }
   uint64_t channels = 0;
-  channels_set_bg_rgb(&channels, 0);
+  ncchannels_set_bg_rgb(&channels, 0);
   ncplane_set_base(pbar, "", 0, channels);
   int posy, posx, pdimy, pdimx;
   ncplane_yx(pbar, &posy, &posx);
   ncplane_dim_yx(pbar, &pdimy, &pdimx);
   ncplane_cursor_move_yx(std, posy - 1, posx - 1);
   channels = 0;
-  channels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
+  ncchannels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
   if(ncplane_rounded_box(std, 0, channels, posy + pdimy, posx + pdimx, 0)){
     ncplane_destroy(pbar);
     return NULL;
   }
   struct ncprogbar_options popts = {0};
-  channel_set_rgb8(&popts.ulchannel, 0x22, 0x22, 0x80);
-  channel_set_rgb8(&popts.urchannel, 0x22, 0x22, 0x80);
-  channel_set_rgb8(&popts.blchannel, 0x80, 0x80, 0x22);
-  channel_set_rgb8(&popts.brchannel, 0x80, 0x80, 0x22);
+  ncchannel_set_rgb8(&popts.ulchannel, 0x22, 0x22, 0x80);
+  ncchannel_set_rgb8(&popts.urchannel, 0x22, 0x22, 0x80);
+  ncchannel_set_rgb8(&popts.blchannel, 0x80, 0x80, 0x22);
+  ncchannel_set_rgb8(&popts.brchannel, 0x80, 0x80, 0x22);
   struct ncprogbar* ncp = ncprogbar_create(pbar, &popts);
   if(ncp == NULL){
     return NULL;
@@ -71,34 +71,34 @@ draw_block(struct ncplane* nn, uint32_t blockstart){
   nccell ul = CELL_TRIVIAL_INITIALIZER, ur = CELL_TRIVIAL_INITIALIZER;
   nccell ll = CELL_TRIVIAL_INITIALIZER, lr = CELL_TRIVIAL_INITIALIZER;
   nccell hl = CELL_TRIVIAL_INITIALIZER, vl = CELL_TRIVIAL_INITIALIZER;
-  cells_rounded_box(nn, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl);
-  cell_set_bg_alpha(&ul, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&ur, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&ll, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&lr, CELL_ALPHA_TRANSPARENT);
-  cell_set_fg_rgb8(&ul, 0xea, 0xaa, 0x00);
-  cell_set_fg_rgb8(&ur, 0x00, 0x30, 0x57);
-  cell_set_fg_rgb8(&ll, 0x00, 0x30, 0x57);
-  cell_set_fg_rgb8(&lr, 0xea, 0xaa, 0x00);
+  nccells_rounded_box(nn, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl);
+  nccell_set_bg_alpha(&ul, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&ur, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&ll, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&lr, NCALPHA_TRANSPARENT);
+  nccell_set_fg_rgb8(&ul, 0xea, 0xaa, 0x00);
+  nccell_set_fg_rgb8(&ur, 0x00, 0x30, 0x57);
+  nccell_set_fg_rgb8(&ll, 0x00, 0x30, 0x57);
+  nccell_set_fg_rgb8(&lr, 0xea, 0xaa, 0x00);
   // see https://github.com/dankamongmen/notcurses/issues/259. we use a random
   // (but dark) background for the perimeter to force refreshing on the box,
   // when it might otherwise be molested by RTL text. hacky and gross :( FIXME
-  int rbg = random() % 20;
-  cell_set_bg_rgb(&ul, rbg);
-  cell_set_bg_rgb(&ur, rbg);
-  cell_set_bg_rgb(&ll, rbg);
-  cell_set_bg_rgb(&lr, rbg);
-  cell_set_fg_rgb8(&hl, 255, 255, 255);
-  cell_set_fg_rgb8(&vl, 255, 255, 255);
-  cell_set_bg_rgb8(&hl, 0, 0, 0);
-  cell_set_bg_rgb8(&vl, 0, 0, 0);
+  int rbg = rand() % 20;
+  nccell_set_bg_rgb(&ul, rbg);
+  nccell_set_bg_rgb(&ur, rbg);
+  nccell_set_bg_rgb(&ll, rbg);
+  nccell_set_bg_rgb(&lr, rbg);
+  nccell_set_fg_rgb8(&hl, 255, 255, 255);
+  nccell_set_fg_rgb8(&vl, 255, 255, 255);
+  nccell_set_bg_rgb8(&hl, 0, 0, 0);
+  nccell_set_bg_rgb8(&vl, 0, 0, 0);
   ncplane_home(nn);
   unsigned control = NCBOXGRAD_TOP | NCBOXGRAD_BOTTOM | NCBOXGRAD_LEFT | NCBOXGRAD_RIGHT;
   if(ncplane_box_sized(nn, &ul, &ur, &ll, &lr, &hl, &vl, dimy, dimx, control)){
     return -1;
   }
-  cell_release(nn, &ul); cell_release(nn, &ur); cell_release(nn, &hl);
-  cell_release(nn, &ll); cell_release(nn, &lr); cell_release(nn, &vl);
+  nccell_release(nn, &ul); nccell_release(nn, &ur); nccell_release(nn, &hl);
+  nccell_release(nn, &ll); nccell_release(nn, &lr); nccell_release(nn, &vl);
   int chunk;
   for(chunk = 0 ; chunk < BLOCKSIZE / CHUNKSIZE ; ++chunk){
     int z;
@@ -146,6 +146,8 @@ int unicodeblocks_demo(struct notcurses* nc){
     const char* name;
     uint32_t start;
   } blocks[] = {
+    // FIXME use full titles, and give several rows to the block name, using
+    //       ncplane_puttext(NCALIGN_CENTER). some here are truncated.
     { .name = "Basic Latin, Latin 1 Supplement, Latin Extended", .start = 0, },
     { .name = "IPA Extensions, Spacing Modifiers, Greek and Coptic", .start = 0x200, },
     { .name = "Cyrillic, Cyrillic Supplement, Armenian, Hebrew", .start = 0x400, },
@@ -224,7 +226,7 @@ int unicodeblocks_demo(struct notcurses* nc){
   }
   ncplane_greyscale(notcurses_stdplane(nc));
   int pbarrow = 4 + BLOCKSIZE / CHUNKSIZE + 4;
-  if(pbarrow > maxy - 1){
+  if(pbarrow > maxy - 2){
     pbarrow = -1;
   }
   struct ncprogbar* pbar = pbar_make(nc, pbarrow);
@@ -248,9 +250,9 @@ int unicodeblocks_demo(struct notcurses* nc){
     return -1;
   }
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_fg_rgb(&channels, 0x004000);
-  channels_set_bg_rgb(&channels, 0x0);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_fg_rgb(&channels, 0x004000);
+  ncchannels_set_bg_rgb(&channels, 0x0);
   ncplane_set_base(header, "", 0, channels);
   for(sindex = 0 ; sindex < sizeof(blocks) / sizeof(*blocks) ; ++sindex){
     ncplane_set_bg_rgb8(n, 0, 0, 0);
