@@ -26,9 +26,9 @@ mathplane(struct notcurses* nc){
   };
   struct ncplane* n = ncplane_create(stdn, &nopts);
   uint64_t channels = 0;
-  channels_set_fg_rgb(&channels, 0x2b50c8); // metallic gold, inverted
-  channels_set_fg_alpha(&channels, CELL_ALPHA_BLEND);
-  channels_set_bg_alpha(&channels, CELL_ALPHA_TRANSPARENT);
+  ncchannels_set_fg_rgb(&channels, 0x2b50c8); // metallic gold, inverted
+  ncchannels_set_fg_alpha(&channels, NCALPHA_BLEND);
+  ncchannels_set_bg_alpha(&channels, NCALPHA_TRANSPARENT);
   ncplane_set_base(n, "", 0, channels);
   ncplane_set_fg_rgb(n, 0xd4af37); // metallic gold
   ncplane_set_bg_rgb(n, 0x0);
@@ -49,22 +49,22 @@ mathplane(struct notcurses* nc){
 // the closer the coordinate is (lower distance), the more we lighten the cell
 static inline int
 lighten(struct ncplane* n, nccell* c, int distance, int y, int x){
-  if(cell_wide_right_p(c)){ // not really a character
+  if(nccell_wide_right_p(c)){ // not really a character
     return 0;
   }
   unsigned r, g, b;
-  cell_fg_rgb8(c, &r, &g, &b);
+  nccell_fg_rgb8(c, &r, &g, &b);
   r += rand() % (64 / (2 * distance + 1) + 1);
   g += rand() % (64 / (2 * distance + 1) + 1);
   b += rand() % (64 / (2 * distance + 1) + 1);
-  cell_set_fg_rgb8_clipped(c, r, g, b);
+  nccell_set_fg_rgb8_clipped(c, r, g, b);
   return ncplane_putc_yx(n, y, x, c);
 }
 
 static inline int
 lightup_surrounding_cells(struct ncplane* n, nccell* lightup, int y, int x){
   lighten(n, lightup, 0, y, x);
-  cell_release(n, lightup);
+  nccell_release(n, lightup);
   return 0;
 }
 
@@ -76,9 +76,9 @@ typedef struct worm {
 
 static void
 init_worm(worm* s, int dimy, int dimx){
-  cell_init(&s->lightup);
-  s->y = random() % dimy;
-  s->x = random() % dimx;
+  nccell_init(&s->lightup);
+  s->y = rand() % dimy;
+  s->x = rand() % dimx;
   s->prevx = 0;
   s->prevy = 0;
 }
@@ -101,7 +101,7 @@ wormy(worm* s, int dimy, int dimx){
   do{ // force a move
     s->y = oldy;
     s->x = oldx;
-    int direction = random() % 4;
+    int direction = rand() % 4;
     switch(direction){
       case 0: --s->y; break;
       case 1: ++s->x; break;
@@ -168,14 +168,14 @@ static int
 message(struct ncplane* n, int maxy, int maxx, int num, int total,
         int bytes_out, int egs_out, int cols_out){
   uint64_t channels = 0;
-  channels_set_fg_alpha(&channels, CELL_ALPHA_TRANSPARENT);
-  channels_set_bg_alpha(&channels, CELL_ALPHA_TRANSPARENT);
+  ncchannels_set_fg_alpha(&channels, NCALPHA_TRANSPARENT);
+  ncchannels_set_bg_alpha(&channels, NCALPHA_TRANSPARENT);
   ncplane_set_base(n, "", 0, channels);
   ncplane_set_fg_rgb8(n, 255, 255, 255);
   ncplane_set_bg_rgb8(n, 32, 64, 32);
   channels = 0;
-  channels_set_fg_rgb8(&channels, 255, 255, 255);
-  channels_set_bg_rgb8(&channels, 32, 64, 32);
+  ncchannels_set_fg_rgb8(&channels, 255, 255, 255);
+  ncchannels_set_bg_rgb8(&channels, 32, 64, 32);
   ncplane_cursor_move_yx(n, 2, 0);
   if(ncplane_rounded_box(n, 0, channels, 4, 56, 0)){
     return -1;
@@ -185,9 +185,9 @@ message(struct ncplane* n, int maxy, int maxx, int num, int total,
   ncplane_putegc_yx(n, 5, 17, "│", NULL);
   ncplane_putegc_yx(n, 6, 17, "╰", NULL);
   nccell hl = CELL_TRIVIAL_INITIALIZER;
-  cell_load(n, &hl, "─");
-  cell_set_fg_rgb8(&hl, 255, 255, 255);
-  cell_set_bg_rgb8(&hl, 32, 64, 32);
+  nccell_load(n, &hl, "─");
+  nccell_set_fg_rgb8(&hl, 255, 255, 255);
+  nccell_set_bg_rgb8(&hl, 32, 64, 32);
   ncplane_hline(n, &hl, 57 - 18 - 1);
   ncplane_putegc_yx(n, 6, 56, "╯", NULL);
   ncplane_putegc_yx(n, 5, 56, "│", NULL);
@@ -197,9 +197,9 @@ message(struct ncplane* n, int maxy, int maxx, int num, int total,
   ncplane_putegc_yx(n, 2, 3, "╨", NULL);
   ncplane_putegc_yx(n, 1, 3, "║", NULL);
   ncplane_putegc_yx(n, 0, 3, "╔", NULL);
-  cell_load(n, &hl, "═");
+  nccell_load(n, &hl, "═");
   ncplane_hline(n, &hl, 20 - 4 - 1);
-  cell_release(n, &hl);
+  nccell_release(n, &hl);
   ncplane_putegc_yx(n, 0, 19, "╗", NULL);
   ncplane_putegc_yx(n, 1, 19, "║", NULL);
   ncplane_putegc_yx(n, 2, 19, "╨", NULL);
@@ -210,7 +210,7 @@ message(struct ncplane* n, int maxy, int maxx, int num, int total,
   ncplane_printf_yx(n, 1, 4, " %03dx%03d (%d/%d) ", maxx, maxy, num + 1, total);
   ncplane_off_styles(n, NCSTYLE_ITALIC);
   ncplane_set_fg_rgb8(n, 224, 128, 224);
-  ncplane_putstr_yx(n, 3, 1, "   🔥 unicode 13, resize awareness, 24b truecolor…🔥   ");
+  ncplane_putstr_yx(n, 3, 1, " 🎆🔥 unicode 13, resize awareness, 24b truecolor…🔥🎆 ");
   ncplane_set_fg_rgb8(n, 255, 255, 255);
   return 0;
 }
@@ -455,10 +455,11 @@ int witherworm_demo(struct notcurses* nc){
   size_t i;
   const size_t screens = sizeof(steps) / sizeof(*steps);
   struct ncplane* n = notcurses_stdplane(nc);
+  bool initial_scroll = ncplane_scrolling_p(n);
   ncplane_set_scrolling(n, true);
   ncplane_erase(n);
   for(i = 0 ; i < screens ; ++i){
-    wchar_t key = NCKEY_INVALID;
+    uint32_t key = NCKEY_INVALID;
     nccell c;
     struct timespec screenend;
     clock_gettime(CLOCK_MONOTONIC, &screenend);
@@ -466,7 +467,7 @@ int witherworm_demo(struct notcurses* nc){
     do{ // (re)draw a screen
       const int start = starts[i];
       int step = steps[i];
-      cell_init(&c);
+      nccell_init(&c);
       int y, x, maxy, maxx;
       ncplane_dim_yx(n, &maxy, &maxx); // might resize
       int rgb = start;
@@ -480,11 +481,11 @@ int witherworm_demo(struct notcurses* nc){
       }
       ncplane_set_bg_rgb8(n, 20, 20, 20);
       do{ // we fill up the screen, however large, bouncing around our strtable
-        s = strs + random() % ((sizeof(strs) / sizeof(*strs)) - 1);
+        s = strs + rand() % ((sizeof(strs) / sizeof(*strs)) - 1);
         size_t idx = 0;
         ncplane_cursor_yx(n, &y, &x);
         while((*s)[idx]){ // each multibyte char of string
-          if(ncplane_set_fg_rgb8(n, channel_r(rgb), channel_g(rgb), channel_b(rgb))){
+          if(ncplane_set_fg_rgb8(n, ncchannel_r(rgb), ncchannel_g(rgb), ncchannel_b(rgb))){
             return -1;
           }
           if(x >= maxx){
@@ -511,6 +512,8 @@ int witherworm_demo(struct notcurses* nc){
             if((r = ncplane_putegc(n, &(*s)[idx], &ulen)) <= 0){
               if(ulen < 0){
                 return -1;
+              }else if(ulen == 0){
+                break; // FIXME work around missing unicode
               }
             }
           }else{
@@ -555,8 +558,8 @@ int witherworm_demo(struct notcurses* nc){
         uint64_t delay = timespec_to_ns(&demodelay);
         delay /= screens;
         struct timespec tv;
-        if(delay > GIG){
-          ns_to_timespec(GIG, &tv);
+        if(delay > NANOSECS_IN_SEC){
+          ns_to_timespec(NANOSECS_IN_SEC, &tv);
         }else{
           ns_to_timespec(delay, &tv);
         }
@@ -591,8 +594,7 @@ int witherworm_demo(struct notcurses* nc){
         DEMO_RENDER(nc);
       }
     }while(key == NCKEY_RESIZE);
-    notcurses_refresh(nc, NULL, NULL);
   }
-  ncplane_set_scrolling(n, false);
+  ncplane_set_scrolling(n, initial_scroll);
   return 0;
 }
