@@ -32,8 +32,8 @@ typedef struct fetched_info {
   char* kernel;                // strdup(uname(2)->name)
   char* kernver;               // strdup(uname(2)->version);
   char* desktop;               // getenv("XDG_CURRENT_DESKTOP")
-  char* shell;                 // getenv("SHELL")
-  char* term;                  // getenv("TERM")
+  const char* shell;           // getenv("SHELL")
+  char* term;                  // ncdirect_detected_terminal(), heap-alloced
   char* lang;                  // getenv("LANG")
   int dimy, dimx;              // extracted from xrandr
   char* cpu_model;             // FIXME don't handle hetero setups yet
@@ -49,10 +49,10 @@ free_fetched_info(fetched_info* fi){
 }
 
 static int
-fetch_env_vars(fetched_info* fi){
+fetch_env_vars(struct ncdirect* nc, fetched_info* fi){
   fi->desktop = getenv("XDG_CURRENT_DESKTOP");
   fi->shell = getenv("SHELL");
-  fi->term = getenv("TERM");
+  fi->term = ncdirect_detected_terminal(nc);
   fi->lang = getenv("LANG");
   return 0;
 }
@@ -62,6 +62,10 @@ static distro_info distros[] = {
     .name = "arch",
     // from core/filesystem
     .logofile = "/usr/share/pixmaps/archlinux.png",
+  }, {
+    .name = "artix",
+    // from system/filesystem
+    .logofile = "/usr/share/pixmaps/artixlinux-logo.png",
   }, {
     .name = "debian",
     // from desktop-base package
@@ -152,12 +156,12 @@ pipe_getline(const char* cmdline){
   char* buf = malloc(BUFSIZ); // gatesv("BUFSIZ bytes is enough for anyone")
   if(fgets(buf, BUFSIZ, p) == NULL){
 //fprintf(stderr, "Error reading from %s (%s)\n", cmdline, strerror(errno));
-    fclose(p);
+    pclose(p);
     free(buf);
     return NULL;
   }
   // FIXME read any remaining junk so as to stave off SIGPIPEs?
-  if(fclose(p)){
+  if(pclose(p)){
     fprintf(stderr, "Error closing pipe (%s)\n", strerror(errno));
     free(buf);
     return NULL;
@@ -299,6 +303,7 @@ typedef enum {
   NCNEO_LINUX,
   NCNEO_FREEBSD,
   NCNEO_DRAGONFLY,
+  NCNEO_XNU,
   NCNEO_UNKNOWN,
 } ncneo_kernel_e;
 
@@ -317,6 +322,8 @@ get_kernel(fetched_info* fi){
     return NCNEO_FREEBSD;
   }else if(strcmp(uts.sysname, "DragonFly") == 0){
     return NCNEO_DRAGONFLY;
+  }else if(strcmp(uts.sysname, "Darwin") == 0){
+    return NCNEO_XNU;
   }
   fprintf(stderr, "Unknown operating system via uname: %s\n", uts.sysname);
   return NCNEO_UNKNOWN;
@@ -344,6 +351,17 @@ dragonfly_ncneofetch(fetched_info* fi){
   return &fbsd;
 }
 
+static const distro_info*
+xnu_ncneofetch(fetched_info* fi){
+  static distro_info fbsd = {
+    .name = "OS X",
+    .logofile = "/System/Library/PrivateFrameworks/LoginUIKit.framework/Versions/A/Frameworks/LoginUICore.framework/Versions/A/Resources/apple@2x.png",
+  };
+  fi->neologo = get_neofetch_art("Darwin");
+  fi->distro_pretty = "OS X 11.4 (Big Sur)";
+  return &fbsd;
+}
+
 static int
 drawpalette(struct ncdirect* nc){
   int psize = ncdirect_palette_size(nc);
@@ -393,7 +411,7 @@ place_infoplane(struct ncdirect* ncd, int planeheight){
   }
   struct notcurses_options opts = {
     .flags = NCOPTION_SUPPRESS_BANNERS | NCOPTION_INHIBIT_SETLOCALE
-              | NCOPTION_NO_ALTERNATE_SCREEN,
+              | NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_NO_CLEAR_BITMAPS,
     .margin_t = cury,
     .margin_b = dimy - (cury + planeheight),
   };
@@ -450,19 +468,20 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
   if(notcurses_cantruecolor(nc)){
     ncplane_printf_aligned(infop, 4, NCALIGN_LEFT, " RGB TERM: %s", fi->term);
     nccell c = CELL_CHAR_INITIALIZER('R');
-    cell_set_styles(&c, NCSTYLE_BOLD);
-    cell_set_fg_rgb8(&c, 0xf0, 0xa0, 0xa0);
+    nccell_set_styles(&c, NCSTYLE_BOLD);
+    nccell_set_fg_rgb8(&c, 0xf0, 0xa0, 0xa0);
     ncplane_putc_yx(infop, 4, 1, &c);
-    cell_load_char(infop, &c, 'G');
-    cell_set_fg_rgb8(&c, 0xa0, 0xf0, 0xa0);
+    nccell_load_char(infop, &c, 'G');
+    nccell_set_fg_rgb8(&c, 0xa0, 0xf0, 0xa0);
     ncplane_putc_yx(infop, 4, 2, &c);
-    cell_load_char(infop, &c, 'B');
-    cell_set_fg_rgb8(&c, 0xa0, 0xa0, 0xf0);
+    nccell_load_char(infop, &c, 'B');
+    nccell_set_fg_rgb8(&c, 0xa0, 0xa0, 0xf0);
     ncplane_putc_yx(infop, 4, 3, &c);
-    cell_set_styles(&c, NCSTYLE_NONE);
+    nccell_set_styles(&c, NCSTYLE_NONE);
   }else{
     ncplane_printf_aligned(infop, 4, NCALIGN_LEFT, " TERM: %s", fi->term);
   }
+  free(fi->term);
   ncplane_printf_aligned(infop, 4, NCALIGN_RIGHT, "Screen0: %dx%d ", fi->dimx, fi->dimy);
   ncplane_printf_aligned(infop, 5, NCALIGN_LEFT, " LANG: %s", fi->lang);
   ncplane_printf_aligned(infop, 5, NCALIGN_RIGHT, "UID: %ju ", (uintmax_t)getuid());
@@ -471,33 +490,33 @@ infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheigh
   nccell ul = CELL_TRIVIAL_INITIALIZER, ur = CELL_TRIVIAL_INITIALIZER;
   nccell ll = CELL_TRIVIAL_INITIALIZER, lr = CELL_TRIVIAL_INITIALIZER;
   nccell hl = CELL_TRIVIAL_INITIALIZER, vl = CELL_TRIVIAL_INITIALIZER;
-  if(cells_rounded_box(infop, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl)){
+  if(nccells_rounded_box(infop, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl)){
     return -1;
   }
-  cell_set_fg_rgb8(&ul, 0x90, 0x90, 0x90);
-  cell_set_fg_rgb8(&ur, 0x90, 0x90, 0x90);
-  cell_set_fg_rgb8(&ll, 0, 0, 0);
-  cell_set_fg_rgb8(&lr, 0, 0, 0);
+  nccell_set_fg_rgb8(&ul, 0x90, 0x90, 0x90);
+  nccell_set_fg_rgb8(&ur, 0x90, 0x90, 0x90);
+  nccell_set_fg_rgb8(&ll, 0, 0, 0);
+  nccell_set_fg_rgb8(&lr, 0, 0, 0);
   unsigned ctrlword = NCBOXGRAD_BOTTOM | NCBOXGRAD_LEFT | NCBOXGRAD_RIGHT;
   if(ncplane_perimeter(infop, &ul, &ur, &ll, &lr, &hl, &vl, ctrlword)){
     return -1;
   }
   ncplane_home(infop);
   uint64_t channels = 0;
-  channels_set_fg_rgb8(&channels, 0, 0xff, 0);
+  ncchannels_set_fg_rgb8(&channels, 0, 0xff, 0);
   ncplane_hline_interp(infop, &hl, planewidth / 2, ul.channels, channels);
   ncplane_hline_interp(infop, &hl, planewidth / 2, channels, ur.channels);
-  cell_release(infop, &ul); cell_release(infop, &ur);
-  cell_release(infop, &ll); cell_release(infop, &lr);
-  cell_release(infop, &hl); cell_release(infop, &vl);
+  nccell_release(infop, &ul); nccell_release(infop, &ur);
+  nccell_release(infop, &ll); nccell_release(infop, &lr);
+  nccell_release(infop, &hl); nccell_release(infop, &vl);
   ncplane_set_fg_rgb8(infop, 0xff, 0xff, 0xff);
   ncplane_set_styles(infop, NCSTYLE_BOLD);
   if(ncplane_printf_aligned(infop, 0, NCALIGN_CENTER, "[ %s@%s ]",
                             fi->username, fi->hostname) < 0){
     return -1;
   }
-  channels_set_fg_rgb8(&channels, 0, 0, 0);
-  channels_set_bg_rgb8(&channels, 0x50, 0x50, 0x50);
+  ncchannels_set_fg_rgb8(&channels, 0, 0, 0);
+  ncchannels_set_bg_rgb8(&channels, 0x50, 0x50, 0x50);
   ncplane_set_base(infop, " ", 0, channels);
   if(notcurses_render(nc)){
     return -1;
@@ -558,12 +577,14 @@ neologo_present(struct ncdirect* nc, const char* nlogo){
     free(lines[i]);
   }
   free(lines);
-  ncdirect_set_fg_rgb(nc, 0xba55d3);
+  ncdirect_set_fg_default(nc);
+  ncdirect_on_styles(nc, NCSTYLE_BOLD | NCSTYLE_ITALIC);
   if(ncdirect_canopen_images(nc)){
     ncdirect_printf_aligned(nc, -1, NCALIGN_CENTER, "(no image file is known for your distro)");
   }else{
     ncdirect_printf_aligned(nc, -1, NCALIGN_CENTER, "(notcurses was compiled without image support)");
   }
+  ncdirect_off_styles(nc, NCSTYLE_BOLD | NCSTYLE_ITALIC);
   return 0;
 }
 
@@ -572,7 +593,6 @@ display_thread(void* vmarshal){
   struct marshal* m = vmarshal;
   drawpalette(m->nc);
   if(ncdirect_canopen_images(m->nc)){
-    ncdirect_check_pixel_support(m->nc);
     if(m->logo){
       if(ncdirect_render_image(m->nc, m->logo, NCALIGN_CENTER,
                                NCBLIT_PIXEL, NCSCALE_SCALE_HIRES) == 0){
@@ -607,6 +627,9 @@ ncneofetch(struct ncdirect* nc){
     case NCNEO_DRAGONFLY:
       fi.distro = dragonfly_ncneofetch(&fi);
       break;
+    case NCNEO_XNU:
+      fi.distro = xnu_ncneofetch(&fi);
+      break;
     case NCNEO_UNKNOWN:
       break;
   }
@@ -622,7 +645,7 @@ ncneofetch(struct ncdirect* nc){
   const bool launched = !pthread_create(&tid, NULL, display_thread, &display_marshal);
   unix_gethostname(&fi);
   unix_getusername(&fi);
-  fetch_env_vars(&fi);
+  fetch_env_vars(nc, &fi);
   fetch_x_props(&fi);
   if(kern == NCNEO_LINUX){
     fetch_cpu_info(&fi);
