@@ -1,5 +1,13 @@
 #include "internal.h"
 
+int loglevel = NCLOGLEVEL_SILENT;
+
+void notcurses_debug_caps(const notcurses* nc, FILE* debugfp){
+  // FIXME deprecated, remove for ABI3
+  (void)nc;
+  (void)debugfp;
+}
+
 static void
 ncpile_debug(const ncpile* p, FILE* debugfp){
   fprintf(debugfp, "  ************************* %16p pile ****************************\n", p);
@@ -7,7 +15,7 @@ ncpile_debug(const ncpile* p, FILE* debugfp){
   const ncplane* prev = NULL;
   int planeidx = 0;
   while(n){
-    fprintf(debugfp, "%04d off y: %3d x: %3d geom y: %3d x: %3d curs y: %3d x: %3d %p %.8s\n",
+    fprintf(debugfp, "%04d off y: %3d x: %3d geom y: %3d x: %3d curs y: %3d x: %3d %p %.4s\n",
             planeidx, n->absy, n->absx, n->leny, n->lenx, n->y, n->x, n, n->name);
     if(n->boundto || n->bnext || n->bprev || n->blist){
       fprintf(debugfp, " bound %p ← %p → %p binds %p\n",
@@ -31,7 +39,7 @@ ncpile_debug(const ncpile* p, FILE* debugfp){
   }
 }
 
-void notcurses_debug(notcurses* nc, FILE* debugfp){
+void notcurses_debug(const notcurses* nc, FILE* debugfp){
   const ncpile* p = ncplane_pile(nc->stdplane);
   fprintf(debugfp, " -------------------------- notcurses debug state -----------------------------\n");
   const ncpile* p0 = p;
