@@ -1,7 +1,9 @@
-#include <poll.h>
+#include <stdio.h>
 #include <fcntl.h>
 #include <unistd.h>
 #include <pthread.h>
+#include "internal.h"
+#ifndef __MINGW64__
 #include <sys/wait.h>
 #include <sys/time.h>
 #ifdef USING_PIDFD
@@ -18,7 +20,6 @@
 #else
 #define NCPOLLEVENTS (POLLIN)
 #endif
-#include "internal.h"
 
 // release the memory and fd, but don't join the thread (since we might be
 // getting called within the thread's context, on a callback).
@@ -109,7 +110,7 @@ ncfdplane_create_internal(ncplane* n, const ncfdplane_options* opts, int fd,
                           ncfdplane_callback cbfxn, ncfdplane_done_cb donecbfxn,
                           bool thread){
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   ncfdplane* ret = malloc(sizeof(*ret));
   if(ret == NULL){
@@ -169,10 +170,14 @@ int ncfdplane_destroy(ncfdplane* n){
 // ncfdplane around the read end, involving creation of a new thread. the
 // parent then returns.
 static pid_t
-launch_pipe_process(int* pipe, int* pidfd){
+launch_pipe_process(int* pipefd, int* pidfd){
   *pidfd = -1;
   int pipes[2];
+#if (defined(__linux__))
   if(pipe2(pipes, O_CLOEXEC)){ // can't use O_NBLOCK here (affects client)
+#else
+  if(pipe(pipes)){ // FIXME manually set O_CLOEXEC
+#endif
     return -1;
   }
   pid_t p = -1;
@@ -193,12 +198,12 @@ launch_pipe_process(int* pipe, int* pidfd){
   }
   if(p == 0){ // child
     if(dup2(pipes[1], STDOUT_FILENO) < 0 || dup2(pipes[1], STDERR_FILENO) < 0){
-      fprintf(stderr, "Couldn't dup() %d (%s)\n", pipes[1], strerror(errno));
+      logerror("Couldn't dup() %d (%s)\n", pipes[1], strerror(errno));
       exit(EXIT_FAILURE);
     }
   }else if(p > 0){ // parent
-    *pipe = pipes[0];
-    set_fd_nonblocking(*pipe, 1, NULL);
+    *pipefd = pipes[0];
+    set_fd_nonblocking(*pipefd, 1, NULL);
   }
   return p;
 }
@@ -310,7 +315,7 @@ ncsubproc* ncsubproc_createv(ncplane* n, const ncsubproc_options* opts,
     return NULL;
   }
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   int fd = -1;
   ncsubproc* ret = malloc(sizeof(*ret));
@@ -345,7 +350,7 @@ ncsubproc* ncsubproc_createvp(ncplane* n, const ncsubproc_options* opts,
     return NULL;
   }
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   int fd = -1;
   ncsubproc* ret = malloc(sizeof(*ret));
@@ -380,7 +385,7 @@ ncsubproc* ncsubproc_createvpe(ncplane* n, const ncsubproc_options* opts,
     return NULL;
   }
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   int fd = -1;
   ncsubproc* ret = malloc(sizeof(*ret));
@@ -392,12 +397,16 @@ ncsubproc* ncsubproc_createvpe(ncplane* n, const ncsubproc_options* opts,
   if(ret->pid == 0){
 #ifdef __linux__
     execvpe(bin, arg, env);
+#elif defined(__APPLE__)
+    (void)env;
+    execvp(bin, arg); // FIXME env?
 #else
     exect(bin, arg, env);
 #endif
-//fprintf(stderr, "Error execv()ing %s\n", bin);
+    logerror("Error execing %s (%s?)\n", bin, strerror(errno));
     exit(EXIT_FAILURE);
   }else if(ret->pid < 0){
+    logerror("Error launching process (%s?)\n", strerror(errno));
     free(ret);
     return NULL;
   }
@@ -417,6 +426,7 @@ int ncsubproc_destroy(ncsubproc* n){
 //fprintf(stderr, "pid: %u pidfd: %d waittid: %u\n", n->pid, n->pidfd, n->waittid);
 #ifdef USING_PIDFD
     if(n->pidfd >= 0){
+      loginfo("Sending SIGKILL to pidfd %d\n", n->pidfd);
       if(syscall(__NR_pidfd_send_signal, n->pidfd, SIGKILL, NULL, 0)){
         kill(n->pid, SIGKILL);
       }
@@ -424,6 +434,7 @@ int ncsubproc_destroy(ncsubproc* n){
 #else
     pthread_mutex_lock(&n->lock);
     if(!n->waited){
+      loginfo("Sending SIGKILL to PID %d\n", n->pid);
       kill(n->pid, SIGKILL);
     }
     pthread_mutex_unlock(&n->lock);
@@ -441,6 +452,7 @@ int ncsubproc_destroy(ncsubproc* n){
     }else{
       pthread_join(n->nfp->tid, NULL);
     }
+    pthread_mutex_destroy(&n->lock);
     free(n);
     if(vret == NULL){
       ret = -1;
@@ -451,7 +463,45 @@ int ncsubproc_destroy(ncsubproc* n){
   }
   return ret;
 }
+#else
+int set_fd_nonblocking(int fd, unsigned state, unsigned* oldstate){ // FIXME
+  logerror("Not implemented for %d %u %p\n", fd, state, oldstate);
+  return -1;
+}
+#endif
 
 ncplane* ncsubproc_plane(ncsubproc* n){
   return n->nfp->ncp;
 }
+
+// if ttyfp is a tty, return a file descriptor extracted from it. otherwise,
+// try to get the controlling terminal. otherwise, return -1.
+int get_tty_fd(FILE* ttyfp){
+  int fd = -1;
+  if(ttyfp){
+    if((fd = fileno(ttyfp)) < 0){
+      logwarn("No file descriptor was available in outfp %p\n", ttyfp);
+    }else{
+      if(isatty(fd)){
+        fd = dup(fd);
+      }else{
+        loginfo("File descriptor %d was not a TTY\n", fd);
+        fd = -1;
+      }
+    }
+  }
+  if(fd < 0){
+    fd = open("/dev/tty", O_RDWR | O_CLOEXEC | O_NOCTTY);
+    if(fd < 0){
+      loginfo("Error opening /dev/tty (%s)\n", strerror(errno));
+    }else{
+      if(!isatty(fd)){
+        loginfo("File descriptor for /dev/tty (%d) is not actually a TTY\n", fd);
+        close(fd);
+        fd = -1;
+      }
+    }
+  }
+  loginfo("Returning TTY fd %d\n", fd);
+  return fd;
+}
