@@ -120,9 +120,9 @@ draw_borders(ncplane* n, unsigned mask, uint64_t channel, direction_e direction)
   int maxx = lenx - 1;
   int maxy = leny - 1;
   nccell ul, ur, ll, lr, hl, vl;
-  cell_init(&ul); cell_init(&ur); cell_init(&hl);
-  cell_init(&ll); cell_init(&lr); cell_init(&vl);
-  if(cells_rounded_box(n, 0, channel, &ul, &ur, &ll, &lr, &hl, &vl)){
+  nccell_init(&ul); nccell_init(&ur); nccell_init(&hl);
+  nccell_init(&ll); nccell_init(&lr); nccell_init(&vl);
+  if(nccells_rounded_box(n, 0, channel, &ul, &ur, &ll, &lr, &hl, &vl)){
     return -1;
   }
 //fprintf(stderr, "drawing borders %p ->%d/%d, mask: %04x\n", w, maxx, maxy, mask);
@@ -161,8 +161,8 @@ draw_borders(ncplane* n, unsigned mask, uint64_t channel, direction_e direction)
       ncplane_putc(n, &lr);
     }
   }
-  cell_release(n, &ul); cell_release(n, &ur); cell_release(n, &hl);
-  cell_release(n, &ll); cell_release(n, &lr); cell_release(n, &vl);
+  nccell_release(n, &ul); nccell_release(n, &ur); nccell_release(n, &hl);
+  nccell_release(n, &ll); nccell_release(n, &lr); nccell_release(n, &vl);
   return ret;
 }
 
@@ -298,7 +298,7 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
     int ll = t->cbfxn(t, direction == DIRECTION_DOWN);
 //fprintf(stderr, "RETURNRETURNRETURN %p %d (%d, %d, %d) DIR %d\n", t, ll, cby, cbleny, leny, direction);
     if(ll > cbleny){
-      logwarn(ncplane_notcurses(nr->p), "Tablet callback returned %d lines, %d allowed\n", ll, cbleny);
+      logwarn("Tablet callback returned %d lines, %d allowed\n", ll, cbleny);
       ll = cbleny;
     }
     if(ll != cbleny){
@@ -307,7 +307,7 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
       if(ll){ // must be smaller than the space we provided; add back bottom
         ncplane_resize_simple(t->cbp, ll, cblenx);
       }else{
-        ncplane_genocide(t->cbp);
+        ncplane_destroy_family(t->cbp);
         t->cbp = NULL;
       }
       // resize the borderplane iff we got smaller
@@ -419,7 +419,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
 //fprintf(stderr, "top: %dx%d @ %d, miny: %d\n", ylen, xlen, y, miny);
   if(boty < miny){
 //fprintf(stderr, "NUKING top!\n");
-    ncplane_genocide(top->p);
+    ncplane_destroy_family(top->p);
     top->p = NULL;
     top->cbp = NULL;
     top = top->next;
@@ -427,7 +427,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
   }else if(y < miny){
     int ynew = ylen - (miny - y);
     if(ynew <= 0){
-      ncplane_genocide(top->p);
+      ncplane_destroy_family(top->p);
       top->p = NULL;
       top->cbp = NULL;
     }else{
@@ -436,7 +436,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
       }
       if(top->cbp){
         if(ynew == !(r->ropts.tabletmask & NCBOXMASK_TOP)){
-          ncplane_genocide(top->cbp);
+          ncplane_destroy_family(top->cbp);
           top->cbp = NULL;
         }else{
           ncplane_dim_yx(top->cbp, &ylen, &xlen);
@@ -458,7 +458,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
 //fprintf(stderr, "bot: %dx%d @ %d, maxy: %d\n", ylen, xlen, y, maxy);
   if(maxy < y){
 //fprintf(stderr, "NUKING bottom!\n");
-    ncplane_genocide(bottom->p);
+    ncplane_destroy_family(bottom->p);
     bottom->p = NULL;
     bottom->cbp = NULL;
     bottom = bottom->prev;
@@ -466,7 +466,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
   }if(maxy < boty){
     int ynew = ylen - (boty - maxy);
     if(ynew <= 0){
-      ncplane_genocide(bottom->p);
+      ncplane_destroy_family(bottom->p);
       bottom->p = NULL;
       bottom->cbp = NULL;
     }else{
@@ -476,7 +476,7 @@ trim_reel_overhang(ncreel* r, nctablet* top, nctablet* bottom){
 //fprintf(stderr, "TRIMMED bottom %p from %d to %d (%d)\n", bottom->p, ylen, ynew, maxy - boty);
       if(bottom->cbp){
         if(ynew == !(r->ropts.tabletmask & NCBOXMASK_BOTTOM)){
-          ncplane_genocide(bottom->cbp);
+          ncplane_destroy_family(bottom->cbp);
           bottom->cbp = NULL;
         }else{
           ncplane_dim_yx(bottom->cbp, &ylen, &xlen);
@@ -596,18 +596,18 @@ clean_reel(ncreel* r){
   if(vft){
     for(nctablet* n = vft->next ; n->p && n != vft ; n = n->next){
 //fprintf(stderr, "CLEANING NEXT: %p (%p)\n", n, n->p);
-      ncplane_genocide(n->p);
+      ncplane_destroy_family(n->p);
       n->p = NULL;
       n->cbp = NULL;
     }
     for(nctablet* n = vft->prev ; n->p && n != vft ; n = n->prev){
 //fprintf(stderr, "CLEANING PREV: %p (%p)\n", n, n->p);
-      ncplane_genocide(n->p);
+      ncplane_destroy_family(n->p);
       n->p = NULL;
       n->cbp = NULL;
     }
 //fprintf(stderr, "CLEANING VFT: %p (%p)\n", vft, vft->p);
-    ncplane_genocide(vft->p);
+    ncplane_destroy_family(vft->p);
     vft->p = NULL;
     vft->cbp = NULL;
     r->vft = NULL;
@@ -669,7 +669,7 @@ int ncreel_redraw(ncreel* nr){
   if(focused){
 //fprintf(stderr, "drawing focused tablet %p dir: %d fulcrum: %d!\n", focused, nr->direction, fulcrum);
     if(ncreel_draw_tablet(nr, focused, fulcrum, fulcrum, DIRECTION_DOWN)){
-      logerror(ncplane_notcurses(nr->p), "Error drawing tablet\n");
+      logerror("Error drawing tablet\n");
       return -1;
     }
 //fprintf(stderr, "drew focused tablet %p -> %p lastdir: %d!\n", focused, focused->p, nr->direction);
@@ -681,25 +681,25 @@ int ncreel_redraw(ncreel* nr){
     if(nr->direction == LASTDIRECTION_DOWN){
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
-        logerror(ncplane_notcurses(nr->p), "Error drawing higher tablets\n");
+        logerror("Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }else{ // DIRECTION_UP
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
-        logerror(ncplane_notcurses(nr->p), "Error drawing higher tablets\n");
+        logerror("Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }
     if(otherend == NULL){
-      logerror(ncplane_notcurses(nr->p), "Error drawing following tablets\n");
+      logerror("Error drawing following tablets\n");
       return -1;
     }
 //notcurses_debug(ncplane_notcurses(nr->p), stderr);
     if(tighten_reel(nr)){
-      logerror(ncplane_notcurses(nr->p), "Error tightening reel\n");
+      logerror("Error tightening reel\n");
       return -1;
     }
 //notcurses_debug(ncplane_notcurses(nr->p), stderr);
@@ -707,7 +707,7 @@ int ncreel_redraw(ncreel* nr){
   nr->vft = nr->tablets; // update the visually-focused tablet pointer
 //fprintf(stderr, "DONE ARRANGING\n");
   if(draw_ncreel_borders(nr)){
-    logerror(ncplane_notcurses(nr->p), "Error drawing reel borders\n");
+    logerror("Error drawing reel borders\n");
     return -1; // enforces specified dimensional minima
   }
   return 0;
@@ -719,10 +719,11 @@ validate_ncreel_opts(ncplane* n, const ncreel_options* ropts){
     return false;
   }
   if(ropts->flags >= (NCREEL_OPTION_CIRCULAR << 1u)){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags 0x%016jx\n", (uintmax_t)ropts->flags);
+    logwarn("Provided unsupported flags 0x%016jx\n", (uintmax_t)ropts->flags);
   }
   if(ropts->flags & NCREEL_OPTION_CIRCULAR){
     if(!(ropts->flags & NCREEL_OPTION_INFINITESCROLL)){
+      logerror("Can't set circular without infinitescroll\n");
       return false; // can't set circular without infinitescroll
     }
   }
@@ -732,9 +733,11 @@ validate_ncreel_opts(ncplane* n, const ncreel_options* ropts){
                             NCBOXMASK_TOP |
                             NCBOXMASK_BOTTOM;
   if(ropts->bordermask > fullmask){
+    logerror("Bad bordermask: 0x%016x\n", ropts->bordermask);
     return false;
   }
   if(ropts->tabletmask > fullmask){
+    logerror("Bad tabletmask: 0x%016x\n", ropts->bordermask);
     return false;
   }
   return true;
@@ -782,8 +785,8 @@ nctablet* ncreel_add(ncreel* nr, nctablet* after, nctablet *before,
                      tabletcb cbfxn, void* opaque){
   nctablet* t;
   if(after && before){
-    if(after->prev != before || before->next != after){
-      logerror(ncplane_notcurses(nr->p), "bad before (%p) / after (%p) spec\n", before, after);
+    if(after->next != before || before->prev != after){
+      logerror("bad before (%p) / after (%p) spec\n", before, after);
       return NULL;
     }
   }else if(!after && !before){
@@ -837,7 +840,7 @@ int ncreel_del(ncreel* nr, struct nctablet* t){
   }
   t->next->prev = t->prev;
   if(t->p){
-    ncplane_genocide(t->p);
+    ncplane_destroy_family(t->p);
   }
   free(t);
   --nr->tabletcount;
