@@ -70,15 +70,15 @@ static int
 ncselector_draw(ncselector* n){
   ncplane_erase(n->ncp);
   nccell transchar = CELL_TRIVIAL_INITIALIZER;
-  cell_set_fg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
+  nccell_set_fg_alpha(&transchar, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&transchar, NCALPHA_TRANSPARENT);
   // if we have a title, we'll draw a riser. the riser is two rows tall, and
   // exactly four columns longer than the title, and aligned to the right. we
   // draw a rounded box. the body will blow part or all of the bottom away.
   int yoff = 0;
   if(n->title){
     size_t riserwidth = n->titlecols + 4;
-    int offx = ncplane_align(n->ncp, NCALIGN_RIGHT, riserwidth);
+    int offx = ncplane_halign(n->ncp, NCALIGN_RIGHT, riserwidth);
     ncplane_cursor_move_yx(n->ncp, 0, 0);
     ncplane_hline(n->ncp, &transchar, offx);
     ncplane_cursor_move_yx(n->ncp, 0, offx);
@@ -92,7 +92,7 @@ ncselector_draw(ncselector* n){
   int bodywidth = ncselector_body_width(n);
   int dimy, dimx;
   ncplane_dim_yx(n->ncp, &dimy, &dimx);
-  int xoff = ncplane_align(n->ncp, NCALIGN_RIGHT, bodywidth);
+  int xoff = ncplane_halign(n->ncp, NCALIGN_RIGHT, bodywidth);
   if(xoff){
     for(int y = yoff + 1 ; y < dimy ; ++y){
       ncplane_cursor_move_yx(n->ncp, y, 0);
@@ -174,12 +174,12 @@ ncselector_draw(ncselector* n){
     }
     n->ncp->channels = n->opchannels;
     if(printidx == n->selected){
-      n->ncp->channels = (uint64_t)channels_bchannel(n->opchannels) << 32u | channels_fchannel(n->opchannels);
+      n->ncp->channels = (uint64_t)ncchannels_bchannel(n->opchannels) << 32u | ncchannels_fchannel(n->opchannels);
     }
     ncplane_printf_yx(n->ncp, yoff, bodyoffset + (n->longop - n->items[printidx].opcolumns), "%s", n->items[printidx].option);
     n->ncp->channels = n->descchannels;
     if(printidx == n->selected){
-      n->ncp->channels = (uint64_t)channels_bchannel(n->descchannels) << 32u | channels_fchannel(n->descchannels);
+      n->ncp->channels = (uint64_t)ncchannels_bchannel(n->descchannels) << 32u | ncchannels_fchannel(n->descchannels);
     }
     ncplane_printf_yx(n->ncp, yoff, bodyoffset + n->longop, " %s", n->items[printidx].desc);
     if(++printidx == n->itemcount){
@@ -238,7 +238,7 @@ ncselector* ncselector_create(ncplane* n, const ncselector_options* opts){
   }
   unsigned itemcount = 0;
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   if(opts->items){
     for(const struct ncselector_item* i = opts->items ; i->option ; ++i){
@@ -564,15 +564,15 @@ static int
 ncmultiselector_draw(ncmultiselector* n){
   ncplane_erase(n->ncp);
   nccell transchar = CELL_TRIVIAL_INITIALIZER;
-  cell_set_fg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
-  cell_set_bg_alpha(&transchar, CELL_ALPHA_TRANSPARENT);
+  nccell_set_fg_alpha(&transchar, NCALPHA_TRANSPARENT);
+  nccell_set_bg_alpha(&transchar, NCALPHA_TRANSPARENT);
   // if we have a title, we'll draw a riser. the riser is two rows tall, and
   // exactly four columns longer than the title, and aligned to the right. we
   // draw a rounded box. the body will blow part or all of the bottom away.
   int yoff = 0;
   if(n->title){
     size_t riserwidth = n->titlecols + 4;
-    int offx = ncplane_align(n->ncp, NCALIGN_RIGHT, riserwidth);
+    int offx = ncplane_halign(n->ncp, NCALIGN_RIGHT, riserwidth);
     ncplane_cursor_move_yx(n->ncp, 0, 0);
     ncplane_hline(n->ncp, &transchar, offx);
     ncplane_rounded_box_sized(n->ncp, 0, n->boxchannels, 3, riserwidth, 0);
@@ -585,7 +585,7 @@ ncmultiselector_draw(ncmultiselector* n){
   int bodywidth = ncmultiselector_body_width(n);
   int dimy, dimx;
   ncplane_dim_yx(n->ncp, &dimy, &dimx);
-  int xoff = ncplane_align(n->ncp, NCALIGN_RIGHT, bodywidth);
+  int xoff = ncplane_halign(n->ncp, NCALIGN_RIGHT, bodywidth);
   if(xoff){
     for(int y = yoff + 1 ; y < dimy ; ++y){
       ncplane_cursor_move_yx(n->ncp, y, 0);
@@ -652,7 +652,7 @@ ncmultiselector_draw(ncmultiselector* n){
     }
     n->ncp->channels = n->descchannels;
     if(printidx == n->current){
-      n->ncp->channels = (uint64_t)channels_bchannel(n->descchannels) << 32u | channels_fchannel(n->descchannels);
+      n->ncp->channels = (uint64_t)ncchannels_bchannel(n->descchannels) << 32u | ncchannels_fchannel(n->descchannels);
     }
     if(notcurses_canutf8(ncplane_notcurses(n->ncp))){
       ncplane_putegc_yx(n->ncp, yoff, bodyoffset, n->items[printidx].selected ? "☒" : "☐", NULL);
@@ -661,12 +661,12 @@ ncmultiselector_draw(ncmultiselector* n){
     }
     n->ncp->channels = n->opchannels;
     if(printidx == n->current){
-      n->ncp->channels = (uint64_t)channels_bchannel(n->opchannels) << 32u | channels_fchannel(n->opchannels);
+      n->ncp->channels = (uint64_t)ncchannels_bchannel(n->opchannels) << 32u | ncchannels_fchannel(n->opchannels);
     }
     ncplane_printf(n->ncp, " %s ", n->items[printidx].option);
     n->ncp->channels = n->descchannels;
     if(printidx == n->current){
-      n->ncp->channels = (uint64_t)channels_bchannel(n->descchannels) << 32u | channels_fchannel(n->descchannels);
+      n->ncp->channels = (uint64_t)ncchannels_bchannel(n->descchannels) << 32u | ncchannels_fchannel(n->descchannels);
     }
     ncplane_printf(n->ncp, "%s", n->items[printidx].desc);
     if(++printidx == n->itemcount){
@@ -834,7 +834,7 @@ ncmultiselector* ncmultiselector_create(ncplane* n, const ncmultiselector_option
     opts = &zeroed;
   }
   if(opts->flags > 0){
-    logwarn(ncplane_notcurses(n), "Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
+    logwarn("Provided unsupported flags %016jx\n", (uintmax_t)opts->flags);
   }
   unsigned itemcount = 0;
   if(opts->items){
