@@ -15,16 +15,35 @@ static bool handling_fatals;
 // saved signal actions, restored in drop_signals() FIXME make an array
 static struct sigaction old_winch;
 static struct sigaction old_cont;
-static struct sigaction old_term;
-static struct sigaction old_int;
+static struct sigaction old_abrt;
+static struct sigaction old_fpe;
 static struct sigaction old_ill;
+static struct sigaction old_int;
 static struct sigaction old_quit;
 static struct sigaction old_segv;
-static struct sigaction old_abrt;
 static struct sigaction old_term;
 
+// Signals we block when we start writing out a frame, so as not to be
+// interrupted in media res (interrupting an escape can lock up a terminal).
+// Prepared in setup_signals(), and never changes across our lifetime.
+static sigset_t wblock_signals;
+
 static int(*fatal_callback)(void*); // fatal handler callback
 
+int block_signals(sigset_t* old_blocked_signals){
+  if(pthread_sigmask(SIG_BLOCK, &wblock_signals, old_blocked_signals)){
+    return -1;
+  }
+  return 0;
+}
+
+int unblock_signals(const sigset_t* old_blocked_signals){
+  if(pthread_sigmask(SIG_SETMASK, old_blocked_signals, NULL)){
+    return -1;
+  }
+  return 0;
+}
+
 int drop_signals(void* nc){
   int ret = -1;
   void* expected = nc;
@@ -36,21 +55,24 @@ int drop_signals(void* nc){
       handling_winch = false;
     }
     if(handling_fatals){
-      sigaction(SIGINT, &old_int, NULL);
-      sigaction(SIGILL, &old_ill, NULL);
-      sigaction(SIGTERM, &old_term, NULL);
-      sigaction(SIGSEGV, &old_segv, NULL);
       sigaction(SIGABRT, &old_abrt, NULL);
+      sigaction(SIGFPE, &old_fpe, NULL);
+      sigaction(SIGILL, &old_ill, NULL);
+      sigaction(SIGINT, &old_int, NULL);
       sigaction(SIGQUIT, &old_quit, NULL);
+      sigaction(SIGSEGV, &old_segv, NULL);
+      sigaction(SIGTERM, &old_term, NULL);
       handling_fatals = false;
     }
     ret = !atomic_compare_exchange_strong(&signal_nc, &expected, NULL);
   }
   pthread_mutex_unlock(&lock);
   if(ret){
-    fprintf(stderr, "Couldn't drop signals with %p\n", nc);
+    fprintf(stderr, "Signals weren't registered for %p (had %p)\n", nc, expected);
   }
-  return ret;
+  // we might not have established any handlers in setup_signals(); always
+  // return 0 here, for now...
+  return 0;
 }
 
 static void
@@ -71,23 +93,29 @@ fatal_handler(int signo, siginfo_t* siginfo, void* v){
     fatal_callback(nc);
     switch(signo){
       case SIGTERM: invoke_old(&old_term, signo, siginfo, v); break;
-      case SIGQUIT: invoke_old(&old_quit, signo, siginfo, v); break;
       case SIGSEGV: invoke_old(&old_segv, signo, siginfo, v); break;
+      case SIGQUIT: invoke_old(&old_quit, signo, siginfo, v); break;
       case SIGINT: invoke_old(&old_int, signo, siginfo, v); break;
       case SIGILL: invoke_old(&old_ill, signo, siginfo, v); break;
+      case SIGFPE: invoke_old(&old_fpe, signo, siginfo, v); break;
       case SIGABRT: invoke_old(&old_abrt, signo, siginfo, v); break;
     }
     raise(signo); // FIXME does this invoke twice? hrmmm
   }
 }
 
-int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
+// this both sets up our signal handlers (unless that behavior has been
+// inhibited), and ensures that only one notcurses/ncdirect context is active
+// at any given time.
+int setup_signals(void* vnc, bool no_quit_sigs, bool no_winch_sig,
                   int(*handler)(void*)){
+  notcurses* nc = vnc;
   void* expected = NULL;
   struct sigaction sa;
-
+  // don't register ourselves if we don't intend to set up signal handlers
+  // we expect NULL (nothing registered), and want to register nc
   if(!atomic_compare_exchange_strong(&signal_nc, &expected, nc)){
-    fprintf(stderr, "%p is already registered for signals\n", expected);
+    loginfo("%p is already registered for signals (provided %p)\n", expected, nc);
     return -1;
   }
   if(!no_winch_sig){
@@ -100,8 +128,7 @@ int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
     ret |= sigaction(SIGCONT, &sa, &old_cont);
     if(ret){
       atomic_store(&signal_nc, NULL);
-      fprintf(stderr, "Error installing term signal handler (%s)\n",
-              strerror(errno));
+      fprintf(stderr, "Error installing term signal handler (%s)\n", strerror(errno));
       return -1;
     }
     handling_winch = true;
@@ -110,6 +137,7 @@ int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
     memset(&sa, 0, sizeof(sa));
     fatal_callback = handler;
     sa.sa_sigaction = fatal_handler;
+    sigaddset(&sa.sa_mask, SIGFPE);
     sigaddset(&sa.sa_mask, SIGILL);
     sigaddset(&sa.sa_mask, SIGINT);
     sigaddset(&sa.sa_mask, SIGQUIT);
@@ -118,6 +146,7 @@ int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
     sigaddset(&sa.sa_mask, SIGTERM);
     sa.sa_flags = SA_SIGINFO | SA_RESETHAND; // don't try fatal signals twice
     int ret = 0;
+    ret |= sigaction(SIGFPE, &sa, &old_fpe);
     ret |= sigaction(SIGILL, &sa, &old_ill);
     ret |= sigaction(SIGINT, &sa, &old_int);
     ret |= sigaction(SIGQUIT, &sa, &old_quit);
@@ -126,11 +155,15 @@ int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
     ret |= sigaction(SIGTERM, &sa, &old_term);
     if(ret){
       atomic_store(&signal_nc, NULL);
-      fprintf(stderr, "Error installing fatal signal handlers (%s)\n",
-              strerror(errno));
+      fprintf(stderr, "Error installing fatal signal handlers (%s)\n", strerror(errno));
       return -1;
     }
     handling_fatals = true;
   }
+  // we don't really want to go blocking SIGSEGV etc while we write, but
+  // we *do* temporarily block user-inititated signals.
+  sigaddset(&wblock_signals, SIGINT);
+  sigaddset(&wblock_signals, SIGTERM);
+  sigaddset(&wblock_signals, SIGQUIT);
   return 0;
 }
