@@ -11,7 +11,6 @@
 #include <unistd.h>
 #include <pthread.h>
 #include <sys/stat.h>
-#include <filesystem>
 #include <sys/types.h>
 #include <ncpp/Direct.hh>
 #ifndef __linux__
@@ -24,7 +23,9 @@ void usage(std::ostream& os, const char* name, int code){
   os << " -l: use a long listing format\n";
   os << " -L: dereference symlink arguments\n";
   os << " -R: list subdirectories recursively\n";
-  os << " -a|--align type: one of left, right, or center\n";
+  os << " -a|--align type: 'left', 'right', or 'center'\n";
+  os << " -b|--blitter blitter: 'ascii', 'half', 'quad', 'sex', 'braille', or 'pixel'\n";
+  os << " -s|--scale scaling: one of 'none', 'hires', 'scale', 'scalehi', or 'stretch'\n";
   os << " -h: print usage information\n";
   os << " -V: print version information\n";
   os << std::flush;
@@ -32,10 +33,19 @@ void usage(std::ostream& os, const char* name, int code){
 }
 
 struct job {
-  std::filesystem::path dir;
+  // FIXME ought be a const std::string, but Mojave and maybe other
+  // platforms (any prior to C++17 for sure) are lamely lacking
+  // std::filesystem. alas.
+  // FIXME ideally we'd be handing off a dirfd, not a path.
+  std::string dir;
   std::string p;
 };
 
+// FIXME see above; we ought have std::filesystem
+auto path_join(const std::string& dir, const std::string& p) -> std::string {
+  return dir + p;
+}
+
 static pthread_mutex_t mtx = PTHREAD_MUTEX_INITIALIZER;
 static pthread_mutex_t outmtx = PTHREAD_MUTEX_INITIALIZER; // guards standard out
 static pthread_cond_t cond = PTHREAD_COND_INITIALIZER;
@@ -49,13 +59,15 @@ struct lsContext {
   bool recursedirs;
   bool directories;
   bool dereflinks;
-  ncalign_e alignment;
+  ncpp::NCAlign alignment;
+  ncblitter_e blitter;
+  ncscale_e scaling;
 };
 
-int handle_path(int dirfd, std::filesystem::path& dir, const char* p, const lsContext& ctx, bool toplevel);
+int handle_path(int dirfd, const std::string& dir, const char* p, const lsContext& ctx, bool toplevel);
 
 // handle a single inode of arbitrary type
-int handle_inode(std::filesystem::path& dir, const char* p, const struct stat* st, const lsContext& ctx){
+int handle_inode(const std::string& dir, const char* p, const struct stat* st, const lsContext& ctx){
   (void)st; // FIXME handle symlink (dereflinks)
   (void)ctx; // FIXME handle symlink (dereflinks)
   pthread_mutex_lock(&mtx);
@@ -65,10 +77,11 @@ int handle_inode(std::filesystem::path& dir, const char* p, const struct stat* s
   return 0;
 }
 
-// if |directories| is true, only print details of |p|, and return. otherwise,
-// if |recursedirs| or |toplevel| is set, we will recurse, passing false as
-// toplevel (but preserving |recursedirs|).
-int handle_dir(int dirfd, std::filesystem::path& pdir, const char* p, const struct stat* st, const lsContext& ctx, bool toplevel){
+// if |ctx->directories| is true, only print details of |p|, and return.
+// otherwise, if |ctx->recursedirs| or |toplevel| is set, we will recurse,
+// passing false for toplevel (but preserving |ctx|).
+int handle_dir(int dirfd, const std::string& pdir, const char* p,
+               const struct stat* st, const lsContext& ctx, bool toplevel){
   if(ctx.directories){
     return handle_inode(pdir, p, st, ctx);
   }
@@ -84,7 +97,6 @@ int handle_dir(int dirfd, std::filesystem::path& pdir, const char* p, const stru
     return -1;
   }
   DIR* dir = fdopendir(newdir);
-  auto subdir = pdir / p;
   if(dir == nullptr){
     std::cerr << "Error opening " << p << ": " << strerror(errno) << std::endl;
     close(newdir);
@@ -93,7 +105,7 @@ int handle_dir(int dirfd, std::filesystem::path& pdir, const char* p, const stru
   struct dirent* dent;
   int r = 0;
   while(errno = 0, (dent = readdir(dir))){
-    r |= handle_path(newdir, subdir, dent->d_name, ctx, false);
+    r |= handle_path(newdir, path_join(pdir, p), dent->d_name, ctx, false);
   }
   if(errno){
     std::cerr << "Error reading from " << p << ": " << strerror(errno) << std::endl;
@@ -115,7 +127,7 @@ int handle_deref(const char* p, const struct stat* st, const lsContext& ctx){
 
 // handle some path |p|, either absolute or relative to |dirfd|. |toplevel| is
 // true iff the path was directly listed on the command line.
-int handle_path(int dirfd, std::filesystem::path& pdir, const char* p, const lsContext& ctx, bool toplevel){
+int handle_path(int dirfd, const std::string& pdir, const char* p, const lsContext& ctx, bool toplevel){
   struct stat st;
   if(fstatat(dirfd, p, &st, AT_NO_AUTOMOUNT)){
     std::cerr << "Error running fstatat(" << p << "): " << strerror(errno) << std::endl;
@@ -142,13 +154,14 @@ void ncls_thread(const lsContext* ctx) {
       job j = work.front();
       work.pop();
       pthread_mutex_unlock(&mtx);
-      auto s = j.dir / j.p;
-      auto faken = ctx->nc.prep_image(s.c_str(), NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES);
+      auto s = path_join(j.dir, j.p);
+      auto faken = ctx->nc.prep_image(s.c_str(), ctx->blitter, ctx->scaling, 0, 0);
       pthread_mutex_lock(&outmtx);
       std::cout << j.p << '\n';
       if(faken){
         ctx->nc.raster_image(faken, ctx->alignment);
       }
+      std::cout << '\n';
       pthread_mutex_unlock(&outmtx);
     }else if(!keep_working){
       pthread_mutex_unlock(&mtx);
@@ -167,8 +180,7 @@ int list_paths(const char* const * argv, const lsContext& ctx){
   }
   int ret = 0;
   while(*argv){
-    std::filesystem::path s;
-    ret |= handle_path(dirfd, s, *argv, ctx, true);
+    ret |= handle_path(dirfd, "", *argv, ctx, true);
     ++argv;
   }
   close(dirfd);
@@ -180,31 +192,51 @@ int main(int argc, char* const * argv){
   bool recursedirs = false;
   bool longlisting = false;
   bool dereflinks = false;
-  ncalign_e alignment = NCALIGN_RIGHT;
+  ncpp::NCAlign alignment = ncpp::NCAlign::Right;
+  ncblitter_e blitter = NCBLIT_PIXEL;
+  // FIXME use NCSCALE_NONE by default unless it's hella big, in which case go
+  // ahead and use NCSCALE_SCALE_HIRES. this makes small images too big. =[
+  ncscale_e scale = NCSCALE_SCALE_HIRES;
   const struct option opts[] = {
     { "align", 1, nullptr, 'a' },
+    { "blitter", 1, nullptr, 'b' },
+    { "scale", 1, nullptr, 's' },
     { "help", 0, nullptr, 'h' },
     { "version", 0, nullptr, 'V' },
     { nullptr, 0, nullptr, 0 },
   };
   int c, lidx;
-  while((c = getopt_long(argc, argv, "Va:dhlLR", opts, &lidx)) != -1){
+  while((c = getopt_long(argc, argv, "Va:b:s:dhlLR", opts, &lidx)) != -1){
     switch(c){
       case 'V':
-        printf("ncls version %s\n", notcurses_version());
+        std::cout << "ncls version " <<  notcurses_version() << std::endl;
         exit(EXIT_SUCCESS);
       case 'a':
         if(strcasecmp(optarg, "left") == 0){
-          alignment = NCALIGN_LEFT;
+          alignment = ncpp::NCAlign::Left;
         }else if(strcasecmp(optarg, "right") == 0){
-          alignment = NCALIGN_RIGHT;
+          alignment = ncpp::NCAlign::Right;
         }else if(strcasecmp(optarg, "center") == 0){
-          alignment = NCALIGN_CENTER;
+          alignment = ncpp::NCAlign::Center;
         }else{
           std::cerr << "Unknown alignment type: " << optarg << "\n";
           usage(std::cerr, argv[0], EXIT_FAILURE);
         }
         break;
+      case 'b':
+        if(notcurses_lex_blitter(optarg, &blitter)){
+          std::cerr << "Invalid blitter specification (got "
+                    << optarg << ")" << std::endl;
+          usage(std::cerr, argv[0], EXIT_FAILURE);
+        }
+        break;
+      case 's':
+        if(notcurses_lex_scalemode(optarg, &scale)){
+          std::cerr << "Invalid scaling specification (got "
+                    << optarg << ")" << std::endl;
+          usage(std::cerr, argv[0], EXIT_FAILURE);
+        }
+        break;
       case 'd':
         directories = true;
         break;
@@ -240,7 +272,10 @@ int main(int argc, char* const * argv){
     directories,
     dereflinks,
     alignment,
+    blitter,
+    scale,
   };
+  ctx.nc.cursor_disable();
   keep_working = true;
   for(auto s = 0u ; s < procs ; ++s){
     threads.emplace_back(std::thread(ncls_thread, &ctx));
