@@ -16,14 +16,7 @@ typedef struct ncvisual_details {
 } ncvisual_details;
 
 auto oiio_details_init(void) -> ncvisual_details* {
-  auto deets = new ncvisual_details{};
-  if(deets){
-    deets->image = nullptr;
-    deets->frame = nullptr;
-    deets->ibuf = nullptr;
-    deets->framenum = 0;
-  }
-  return deets;
+  return new ncvisual_details{};
 }
 
 auto oiio_details_destroy(ncvisual_details* deets) -> void {
@@ -33,6 +26,14 @@ auto oiio_details_destroy(ncvisual_details* deets) -> void {
   delete deets;
 }
 
+auto oiio_details_seed(ncvisual* ncv) -> void {
+  int pixels = ncv->pixy * ncv->pixx;
+  ncv->details->frame = std::make_unique<uint32_t[]>(pixels);
+  OIIO::ImageSpec rgbaspec{ncv->pixx, ncv->pixy, 4};
+  ncv->details->ibuf = std::make_unique<OIIO::ImageBuf>(rgbaspec, ncv->data);
+//fprintf(stderr, "got pixel_stride: %ld %ld\n", ncv->details->ibuf->pixel_stride(), ncv->details->ibuf->scanline_stride());
+}
+
 auto oiio_create() -> ncvisual* {
   auto nc = new ncvisual{};
   if((nc->details = oiio_details_init()) == nullptr){
@@ -63,7 +64,7 @@ int oiio_decode(ncvisual* nc) {
     std::fill(nc->details->frame.get(), nc->details->frame.get() + pixels, 0xfffffffful);
   }
 //fprintf(stderr, "READING: %d %ju\n", nc->details->image->current_subimage(), nc->details->framenum);
-  if(!nc->details->image->read_image(nc->details->framenum++, 0, 0, spec.nchannels, OIIO::TypeDesc(OIIO::TypeDesc::UINT8, 4), nc->details->frame.get(), 4)){
+  if(!nc->details->image->read_image(nc->details->framenum++, 0, 0, spec.nchannels, OIIO::TypeDesc(OIIO::TypeDesc::UINT8), nc->details->frame.get(), 4)){
     return -1;
   }
 //fprintf(stderr, "READ: %d %ju\n", nc->details->image->current_subimage(), nc->details->framenum);
@@ -76,15 +77,15 @@ int oiio_decode(ncvisual* nc) {
       nc->details->frame[i] >> 24
       );
 }*/
-  nc->cols = spec.width;
-  nc->rows = spec.height;
-  nc->rowstride = nc->cols * 4;
+  nc->pixx = spec.width;
+  nc->pixy = spec.height;
+  nc->rowstride = nc->pixx * 4;
   OIIO::ImageSpec rgbaspec = spec;
   rgbaspec.nchannels = 4;
   nc->details->ibuf = std::make_unique<OIIO::ImageBuf>(rgbaspec, nc->details->frame.get());
 //fprintf(stderr, "SUBS: %d\n", nc->details->ibuf->nsubimages());
   ncvisual_set_data(nc, static_cast<uint32_t*>(nc->details->ibuf->localpixels()), false);
-//fprintf(stderr, "POST-DECODE DATA: %d %d %p %p\n", nc->rows, nc->cols, nc->data, nc->details->ibuf->localpixels());
+//fprintf(stderr, "POST-DECODE DATA: %d %d %p %p\n", nc->pixy, nc->pixx, nc->data, nc->details->ibuf->localpixels());
   return 0;
 }
 
@@ -126,19 +127,15 @@ int oiio_decode_loop(ncvisual* ncv){
 
 // resize, converting to RGBA (if necessary) along the way
 int oiio_resize(ncvisual* nc, int rows, int cols) {
-//fprintf(stderr, "%d/%d -> %d/%d on the resize\n", ncv->rows, ncv->cols, rows, cols);
+//fprintf(stderr, "%d/%d -> %d/%d on the resize\n", nc->pixy, nc->pixx, rows, cols);
   auto ibuf = std::make_unique<OIIO::ImageBuf>();
-  if(nc->details->ibuf && (nc->cols != cols || nc->rows != rows)){ // scale it
-    OIIO::ImageSpec sp{};
-    sp.width = cols;
-    sp.height = rows;
-    ibuf->reset(sp, OIIO::InitializePixels::Yes);
+  if(nc->details->ibuf && (nc->pixx != cols || nc->pixy != rows)){ // scale it
     OIIO::ROI roi(0, cols, 0, rows, 0, 1, 0, 4);
     if(!OIIO::ImageBufAlgo::resize(*ibuf, *nc->details->ibuf, "", 0, roi)){
       return -1;
     }
-    nc->cols = cols;
-    nc->rows = rows;
+    nc->pixx = cols;
+    nc->pixy = rows;
     nc->rowstride = cols * 4;
     ncvisual_set_data(nc, static_cast<uint32_t*>(ibuf->localpixels()), false);
 //fprintf(stderr, "HAVE SOME NEW DATA: %p\n", ibuf->localpixels());
@@ -148,57 +145,58 @@ int oiio_resize(ncvisual* nc, int rows, int cols) {
 }
 
 int oiio_blit(struct ncvisual* ncv, int rows, int cols,
-                  ncplane* n, const struct blitset* bset,
-                  int placey, int placex, int begy, int begx,
-                  int leny, int lenx, bool blendcolors) {
-//fprintf(stderr, "%d/%d -> %d/%d on the resize\n", ncv->rows, ncv->cols, rows, cols);
+              ncplane* n, const struct blitset* bset,
+              const blitterargs* bargs) {
+//fprintf(stderr, "%d/%d -> %d/%d on the resize\n", ncv->pixy, ncv->pixx, rows, cols);
   void* data = nullptr;
-  int stride = 0;
+  int stride;
   auto ibuf = std::make_unique<OIIO::ImageBuf>();
-  if(ncv->details->ibuf && (ncv->cols != cols || ncv->rows != rows)){ // scale it
-    OIIO::ImageSpec sp{};
-    sp.width = cols;
-    sp.height = rows;
-    ibuf->reset(sp, OIIO::InitializePixels::Yes);
+  if(ncv->details->ibuf && (ncv->pixx != cols || ncv->pixy != rows)){ // scale it
+    // FIXME need to honor leny/lenx and begy/begx
     OIIO::ROI roi(0, cols, 0, rows, 0, 1, 0, 4);
     if(!OIIO::ImageBufAlgo::resize(*ibuf, *ncv->details->ibuf, "", 0, roi)){
       return -1;
     }
-    stride = cols * 4;
+    stride = ibuf->scanline_stride();
     data = ibuf->localpixels();
 //fprintf(stderr, "HAVE SOME NEW DATA: %p\n", ibuf->localpixels());
   }else{
     data = ncv->data;
     stride = ncv->rowstride;
   }
-  return oiio_blit_dispatch(n, bset, placey, placex, stride, data,
-		            begy, begx, leny, lenx, blendcolors);
-  return 0;
+//std::cerr << "output: " << ibuf->roi() << " stride: " << stride << " pstride: " << pstride << std::endl;
+  return oiio_blit_dispatch(n, bset, stride, data, rows, cols, bargs);
 }
 
 // FIXME before we can enable this, we need build an OIIO::APPBUFFER-style
 // ImageBuf in ncvisual in ncvisual_from_rgba().
 /*
 auto ncvisual_rotate(ncvisual* ncv, double rads) -> int {
-  OIIO::ROI roi(0, ncv->cols, 0, ncv->rows, 0, 1, 0, 4);
+  OIIO::ROI roi(0, ncv->pixx, 0, ncv->pixy, 0, 1, 0, 4);
   auto tmpibuf = std::move(*ncv->details->ibuf);
   ncv->details->ibuf = std::make_unique<OIIO::ImageBuf>();
   OIIO::ImageSpec sp{};
-  sp.set_format(OIIO::TypeDesc(OIIO::TypeDesc::UINT8, 4));
+  sp.set_format(OIIO::TypeDesc(OIIO::TypeDesc::UINT8));
   sp.nchannels = 4;
   ncv->details->ibuf->reset();
   if(!OIIO::ImageBufAlgo::rotate(*ncv->details->ibuf, tmpibuf, rads, "", 0, true, roi)){
     return NCERR_DECODE; // FIXME need we do anything further?
   }
-  ncv->rowstride = ncv->cols * 4;
+  ncv->rowstride = ncv->pixx * 4;
   ncvisual_set_data(ncv, static_cast<uint32_t*>(ncv->details->ibuf->localpixels()), false);
   return NCERR_SUCCESS;
 }
 */
 
+auto oiio_destroy(ncvisual* ncv) -> void {
+  if(ncv){
+    oiio_details_destroy(ncv->details);
+  }
+}
+
 // FIXME would be nice to have OIIO::attributes("libraries") in here
-void oiio_printbanner(const struct notcurses* nc __attribute__ ((unused))){
-  printf("  openimageio %s\n", OIIO_VERSION_STRING);
+void oiio_printbanner(const struct notcurses* nc){
+  fprintf(nc->ttyfp, "openimageio %s\n", OIIO_VERSION_STRING);
 }
 
 #endif
