@@ -4,7 +4,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <locale.h>
-#include <sys/ioctl.h>
 #include <notcurses/direct.h>
 
 // can we leave what was already on the screen there? (narrator: it seems not)
@@ -27,11 +26,11 @@ int main(void){
   fflush(stdout);
   int ret = 0;
   ret |= ncdirect_set_fg_rgb(n, 0xff8080);
-  ret |= ncdirect_on_styles(n, NCSTYLE_STANDOUT);
+  ret |= ncdirect_on_styles(n, NCSTYLE_BOLD);
   printf(" erp erp \n");
   ret |= ncdirect_set_fg_rgb(n, 0x80ff80);
   printf(" erp erp \n");
-  ret |= ncdirect_off_styles(n, NCSTYLE_STANDOUT);
+  ret |= ncdirect_off_styles(n, NCSTYLE_BOLD);
   printf(" erp erp \n");
   ret |= ncdirect_set_fg_rgb(n, 0xff8080);
   printf(" erp erp \n");
@@ -45,12 +44,6 @@ int main(void){
     y += 2; // we just went down two lines
     while(y > 3){
       ret = -1;
-      const int up = y >= 3 ? 3 : y;
-      if(ncdirect_cursor_up(n, up)){
-        break;
-      }
-      fflush(stdout);
-      y -= up;
       int newy;
       if(ncdirect_cursor_yx(n, &newy, NULL)){
         break;
@@ -61,6 +54,12 @@ int main(void){
       }
       printf("\n\tRead cursor position: y: %d x: %d\n", newy, x);
       y += 2;
+      const int up = 3;
+      if(ncdirect_cursor_up(n, up)){
+        break;
+      }
+      fflush(stdout);
+      y -= up;
       ret = 0;
     }
   }else{
