@@ -50,7 +50,7 @@ hbar_make(struct notcurses* nc, uint64_t flags){
   ncplane_dim_yx(pbar, &pdimy, &pdimx);
   ncplane_cursor_move_yx(std, posy - 1, posx - 1);
   uint64_t channels = 0;
-  channels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
+  ncchannels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
   if(ncplane_rounded_box(std, 0, channels, posy + pdimy, posx + pdimx, 0)){
     ncplane_destroy(pbar);
     return NULL;
@@ -58,10 +58,10 @@ hbar_make(struct notcurses* nc, uint64_t flags){
   struct ncprogbar_options popts = {
     .flags = flags,
   };
-  channel_set_rgb8(&popts.ulchannel, 0x80, 0x22, 0x22);
-  channel_set_rgb8(&popts.urchannel, 0x22, 0x22, 0x80);
-  channel_set_rgb8(&popts.blchannel, 0x22, 0x80, 0x22);
-  channel_set_rgb8(&popts.brchannel, 0x80, 0x22, 0x22);
+  ncchannel_set_rgb8(&popts.ulchannel, 0x80, 0x22, 0x22);
+  ncchannel_set_rgb8(&popts.urchannel, 0x22, 0x22, 0x80);
+  ncchannel_set_rgb8(&popts.blchannel, 0x22, 0x80, 0x22);
+  ncchannel_set_rgb8(&popts.brchannel, 0x80, 0x22, 0x22);
   struct ncprogbar* ncp = ncprogbar_create(pbar, &popts);
   if(ncp == NULL){
     return NULL;
@@ -90,7 +90,7 @@ pbar_make(struct notcurses* nc, uint64_t flags){
   ncplane_dim_yx(pbar, &pdimy, &pdimx);
   ncplane_cursor_move_yx(std, posy - 1, posx - 1);
   uint64_t channels = 0;
-  channels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
+  ncchannels_set_fg_rgb8(&channels, 0, 0xde, 0xde);
   if(ncplane_rounded_box(std, 0, channels, posy + pdimy, posx + pdimx, 0)){
     ncplane_destroy(pbar);
     return NULL;
@@ -98,10 +98,10 @@ pbar_make(struct notcurses* nc, uint64_t flags){
   struct ncprogbar_options popts = {
     .flags = flags,
   };
-  channel_set_rgb8(&popts.ulchannel, 0x80, 0xcc, 0xcc);
-  channel_set_rgb8(&popts.urchannel, 0xcc, 0xcc, 0x80);
-  channel_set_rgb8(&popts.blchannel, 0xcc, 0x80, 0xcc);
-  channel_set_rgb8(&popts.brchannel, 0x80, 0xcc, 0xcc);
+  ncchannel_set_rgb8(&popts.ulchannel, 0x80, 0xcc, 0xcc);
+  ncchannel_set_rgb8(&popts.urchannel, 0xcc, 0xcc, 0x80);
+  ncchannel_set_rgb8(&popts.blchannel, 0xcc, 0x80, 0xcc);
+  ncchannel_set_rgb8(&popts.brchannel, 0x80, 0xcc, 0xcc);
   struct ncprogbar* ncp = ncprogbar_create(pbar, &popts);
   if(ncp == NULL){
     return NULL;
