@@ -46,6 +46,7 @@ auto main(int argc, const char** argv) -> int {
     .name = "read",
     .resizecb = nullptr,
     .flags = 0,
+    .margin_b = 0, .margin_r = 0,
   };
   struct ncplane* rp = ncplane_create(**n, &nopts);
   ncplane_set_base(rp, "░", 0, 0);
@@ -55,7 +56,7 @@ auto main(int argc, const char** argv) -> int {
   }
   ncinput ni;
   nc.render();
-  while(nc.getc(true, &ni) != (char32_t)-1){
+  while(nc.get(true, &ni) != (char32_t)-1){
     if(ni.ctrl && ni.id == 'L'){
       notcurses_refresh(nc, NULL, NULL);
     }else if((ni.ctrl && ni.id == 'D') || ni.id == NCKEY_ENTER){
@@ -68,8 +69,8 @@ auto main(int argc, const char** argv) -> int {
       int tgeomy, tgeomx, vgeomy, vgeomx;
       ncplane_dim_yx(tplane, &tgeomy, &tgeomx);
       ncplane_dim_yx(ncp, &vgeomy, &vgeomx);
-      (*n)->printf(0, 0, "Scroll: %lc Cursor: %03d/%03d Viewgeom: %03d/%03d Textgeom: %03d/%03d",
-                   horscroll ? L'✔' : L'🗴', ncpy, ncpx, vgeomy, vgeomx, tgeomy, tgeomx);
+      (*n)->printf(0, 0, "Scroll: %c Cursor: %03d/%03d Viewgeom: %03d/%03d Textgeom: %03d/%03d",
+                   horscroll ? '+' : '-', ncpy, ncpx, vgeomy, vgeomx, tgeomy, tgeomx);
       nc.render();
     }
   }
