@@ -103,11 +103,31 @@ TEST_CASE("Plane") {
     CHECK(0 > ncplane_set_fg_rgb8(n_, 256, 256, 256));
   }
 
+  // Verify we can emit a NUL character, and it advances the cursor after
+  // wiping out whatever we printed it atop.
+  SUBCASE("EmitNULCell") {
+    nccell c = CELL_CHAR_INITIALIZER('a');
+    CHECK(0 < ncplane_putc_yx(n_, 0, 0, &c));
+    CHECK(0 == strcmp("a", ncplane_at_yx(n_, 0, 0, nullptr, nullptr)));
+    int y, x;
+    ncplane_cursor_yx(n_, &y, &x);
+    CHECK(0 == y);
+    CHECK(1 == x);
+    CHECK(0 == notcurses_render(nc_));
+    c = CELL_TRIVIAL_INITIALIZER;
+    CHECK(0 < ncplane_putc_yx(n_, 0, 0, &c));
+    CHECK(0 == strcmp("", ncplane_at_yx(n_, 0, 0, nullptr, nullptr)));
+    ncplane_cursor_yx(n_, &y, &x);
+    CHECK(0 == y);
+    CHECK(1 == x);
+    CHECK(0 == notcurses_render(nc_));
+  }
+
   // Verify we can emit a multibyte character, and it advances the cursor
   SUBCASE("EmitCell") {
     const char cchar[] = "✔";
     nccell c{};
-    CHECK(strlen(cchar) == cell_load(n_, &c, cchar));
+    CHECK(strlen(cchar) == nccell_load(n_, &c, cchar));
     CHECK(0 < ncplane_putc(n_, &c));
     int x, y;
     ncplane_cursor_yx(n_, &y, &x);
@@ -174,7 +194,7 @@ TEST_CASE("Plane") {
     REQUIRE(0 < y);
     REQUIRE(0 < x);
     nccell c{};
-    cell_load(n_, &c, "-");
+    nccell_load(n_, &c, "-");
     for(int yidx = 0 ; yidx < y ; ++yidx){
       CHECK(0 == ncplane_cursor_move_yx(n_, yidx, 1));
       CHECK(x - 2 == ncplane_hline(n_, &c, x - 2));
@@ -183,7 +203,7 @@ TEST_CASE("Plane") {
       CHECK(yidx == posy);
       CHECK(x - 1 == posx);
     }
-    cell_release(n_, &c);
+    nccell_release(n_, &c);
     CHECK(0 == notcurses_render(nc_));
   }
 
@@ -193,7 +213,7 @@ TEST_CASE("Plane") {
     REQUIRE(0 < y);
     REQUIRE(0 < x);
     nccell c{};
-    cell_load(n_, &c, "|");
+    nccell_load(n_, &c, "|");
     for(int xidx = 1 ; xidx < x - 1 ; ++xidx){
       CHECK(0 == ncplane_cursor_move_yx(n_, 1, xidx));
       CHECK(y - 2 == ncplane_vline(n_, &c, y - 2));
@@ -202,7 +222,7 @@ TEST_CASE("Plane") {
       CHECK(y - 2 == posy);
       CHECK(xidx == posx - 1);
     }
-    cell_release(n_, &c);
+    nccell_release(n_, &c);
     CHECK(0 == notcurses_render(nc_));
   }
 
@@ -213,7 +233,7 @@ TEST_CASE("Plane") {
     REQUIRE(2 < y);
     REQUIRE(2 < x);
     nccell ul{}, ll{}, lr{}, ur{}, hl{}, vl{};
-    REQUIRE(0 == cells_rounded_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
+    REQUIRE(0 == nccells_rounded_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
     CHECK_GT(0, ncplane_box(n_, &ul, &ur, &ll, &lr, &hl, &vl, y + 1, x + 1, 0));
     CHECK(0 == ncplane_cursor_move_yx(n_, 1, 0));
     CHECK_GT(0, ncplane_box(n_, &ul, &ur, &ll, &lr, &hl, &vl, y, x, 0));
@@ -313,15 +333,15 @@ TEST_CASE("Plane") {
     nccell cell1 = CELL_TRIVIAL_INITIALIZER;
     nccell cell2 = CELL_TRIVIAL_INITIALIZER;
     nccell cell3 = CELL_TRIVIAL_INITIALIZER;
-    auto u1 = cell_load(n_, &cell1, w1);
-    auto u2 = cell_load(n_, &cell2, w2);
-    auto u3 = cell_load(n_, &cell3, w3);
+    auto u1 = nccell_load(n_, &cell1, w1);
+    auto u2 = nccell_load(n_, &cell2, w2);
+    auto u3 = nccell_load(n_, &cell3, w3);
     REQUIRE(2 == u1);
     REQUIRE(3 == u2);
     REQUIRE(1 == u3);
-    cell_release(n_, &cell1);
-    cell_release(n_, &cell2);
-    cell_release(n_, &cell3);
+    nccell_release(n_, &cell1);
+    nccell_release(n_, &cell2);
+    nccell_release(n_, &cell3);
   }
 
   SUBCASE("CellDuplicateCombining") {
@@ -331,24 +351,24 @@ TEST_CASE("Plane") {
     nccell cell1 = CELL_TRIVIAL_INITIALIZER;
     nccell cell2 = CELL_TRIVIAL_INITIALIZER;
     nccell cell3 = CELL_TRIVIAL_INITIALIZER;
-    auto u1 = cell_load(n_, &cell1, w1);
-    auto u2 = cell_load(n_, &cell2, w2);
-    auto u3 = cell_load(n_, &cell3, w3);
+    auto u1 = nccell_load(n_, &cell1, w1);
+    auto u2 = nccell_load(n_, &cell2, w2);
+    auto u3 = nccell_load(n_, &cell3, w3);
     REQUIRE(2 == u1);
     REQUIRE(3 == u2);
     REQUIRE(1 == u3);
     nccell cell4 = CELL_TRIVIAL_INITIALIZER;
     nccell cell5 = CELL_TRIVIAL_INITIALIZER;
     nccell cell6 = CELL_TRIVIAL_INITIALIZER;
-    CHECK(0 == cell_duplicate(n_, &cell4, &cell1));
-    CHECK(0 == cell_duplicate(n_, &cell5, &cell2));
-    CHECK(0 == cell_duplicate(n_, &cell6, &cell3));
-    cell_release(n_, &cell1);
-    cell_release(n_, &cell2);
-    cell_release(n_, &cell3);
-    cell_release(n_, &cell4);
-    cell_release(n_, &cell5);
-    cell_release(n_, &cell6);
+    CHECK(0 == nccell_duplicate(n_, &cell4, &cell1));
+    CHECK(0 == nccell_duplicate(n_, &cell5, &cell2));
+    CHECK(0 == nccell_duplicate(n_, &cell6, &cell3));
+    nccell_release(n_, &cell1);
+    nccell_release(n_, &cell2);
+    nccell_release(n_, &cell3);
+    nccell_release(n_, &cell4);
+    nccell_release(n_, &cell5);
+    nccell_release(n_, &cell6);
   }
 
   SUBCASE("CellMultiColumn") {
@@ -356,16 +376,16 @@ TEST_CASE("Plane") {
     const char* w2 = "N";
     nccell c1 = CELL_TRIVIAL_INITIALIZER;
     nccell c2 = CELL_TRIVIAL_INITIALIZER;
-    auto u1 = cell_load(n_, &c1, w1);
-    auto u2 = cell_load(n_, &c2, w2);
+    auto u1 = nccell_load(n_, &c1, w1);
+    auto u2 = nccell_load(n_, &c2, w2);
     REQUIRE(0 < u1);
     REQUIRE(0 < u2);
     REQUIRE(strlen(w1) == u1);
     REQUIRE(strlen(w2) == u2);
-    CHECK(ncstrwidth(w1) == 1 + cell_double_wide_p(&c1));
-    CHECK_FALSE(cell_double_wide_p(&c2));
-    cell_release(n_, &c1);
-    cell_release(n_, &c2);
+    CHECK(ncstrwidth(w1) == 1 + nccell_double_wide_p(&c1));
+    CHECK_FALSE(nccell_double_wide_p(&c2));
+    nccell_release(n_, &c1);
+    nccell_release(n_, &c2);
   }
 
   // verifies that the initial userptr is what we provided, that it is a nullptr
@@ -382,6 +402,7 @@ TEST_CASE("Plane") {
       .cols = x,
       .userptr = sentinel,
       .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ncp = ncplane_create(n_, &nopts);
     REQUIRE(ncp);
@@ -405,6 +426,7 @@ TEST_CASE("Plane") {
       .rows = y,
       .cols = x,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ncp = ncplane_create(n_, &nopts);
     REQUIRE(ncp);
@@ -430,6 +452,7 @@ TEST_CASE("Plane") {
       .rows = y,
       .cols = x,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ncp = ncpile_create(nc_, &nopts);
     REQUIRE(ncp);
@@ -461,6 +484,7 @@ TEST_CASE("Plane") {
       .rows = maxy,
       .cols = maxx,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* newp = ncplane_create(n_, &nopts);
     REQUIRE(newp);
@@ -507,6 +531,7 @@ TEST_CASE("Plane") {
       .rows = maxy,
       .cols = maxx,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* newp = ncplane_create(n_, &nopts);
     REQUIRE(newp);
@@ -553,7 +578,7 @@ TEST_CASE("Plane") {
     CHECK(0 == testcell.gcluster);
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
-    cell_release(n_, &testcell);
+    nccell_release(n_, &testcell);
     int dimy, dimx;
     ncplane_dim_yx(n_, &dimy, &dimx);
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 1, dimx - strlen(STR2)));
@@ -591,7 +616,7 @@ TEST_CASE("Plane") {
     CHECK(0 == testcell.gcluster);
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
-    cell_release(n_, &testcell);
+    nccell_release(n_, &testcell);
     int dimy, dimx;
     ncplane_dim_yx(n_, &dimy, &dimx);
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 1, dimx - mbstowcs(nullptr, STR2, 0)));
@@ -604,12 +629,12 @@ TEST_CASE("Plane") {
     REQUIRE(0 == ncplane_putstr(n_, STR3));
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 0, 0));
     REQUIRE(0 < ncplane_at_cursor_cell(n_, &testcell)); // want first char of STR1
-    CHECK(!strcmp("Σ", cell_extended_gcluster(n_, &testcell)));
+    CHECK(!strcmp("Σ", nccell_extended_gcluster(n_, &testcell)));
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
     REQUIRE(0 == ncplane_cursor_move_yx(n_, 1, dimx - mbstowcs(nullptr, STR2, 0)));
     REQUIRE(0 < ncplane_at_cursor_cell(n_, &testcell)); // want first char of STR2
-    CHECK(!strcmp("α", cell_extended_gcluster(n_, &testcell)));
+    CHECK(!strcmp("α", nccell_extended_gcluster(n_, &testcell)));
     CHECK(0 == testcell.stylemask);
     CHECK(0 == testcell.channels);
     // FIXME maybe check all cells?
@@ -655,15 +680,15 @@ TEST_CASE("Plane") {
     REQUIRE(20 < dimy);
     REQUIRE(40 < dimx);
     nccell ul{}, ll{}, lr{}, ur{}, hl{}, vl{};
-    REQUIRE(0 == cells_double_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
-    CHECK(0 == channels_set_fg_rgb8(&ul.channels, 255, 0, 0));
-    CHECK(0 == channels_set_fg_rgb8(&ur.channels, 0, 255, 0));
-    CHECK(0 == channels_set_fg_rgb8(&ll.channels, 0, 0, 255));
-    CHECK(0 == channels_set_fg_rgb8(&lr.channels, 255, 255, 255));
-    CHECK(0 == channels_set_bg_rgb8(&ul.channels, 0, 255, 255));
-    CHECK(0 == channels_set_bg_rgb8(&ur.channels, 255, 0, 255));
-    CHECK(0 == channels_set_bg_rgb8(&ll.channels, 255, 255, 0));
-    CHECK(0 == channels_set_bg_rgb8(&lr.channels, 0, 0, 0));
+    REQUIRE(0 == nccells_double_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ul.channels, 255, 0, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ur.channels, 0, 255, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ll.channels, 0, 0, 255));
+    CHECK(0 == ncchannels_set_fg_rgb8(&lr.channels, 255, 255, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ul.channels, 0, 255, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ur.channels, 255, 0, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ll.channels, 255, 255, 0));
+    CHECK(0 == ncchannels_set_bg_rgb8(&lr.channels, 0, 0, 0));
     // we'll try all 16 gradmasks in sideszXsidesz configs in a 4x4 map
     unsigned gradmask = 0;
     for(auto y0 = 0 ; y0 < 4 ; ++y0){
@@ -693,20 +718,20 @@ TEST_CASE("Plane") {
     REQUIRE(20 < dimy);
     REQUIRE(40 < dimx);
     nccell ul{}, ll{}, lr{}, ur{}, hl{}, vl{};
-    REQUIRE(0 == cells_rounded_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
+    REQUIRE(0 == nccells_rounded_box(n_, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
     // we'll try all 16 boxmasks in sideszXsidesz configurations in a 4x4 map
-    CHECK(0 == channels_set_fg_rgb8(&ul.channels, 255, 0, 0));
-    CHECK(0 == channels_set_fg_rgb8(&ur.channels, 0, 255, 0));
-    CHECK(0 == channels_set_fg_rgb8(&ll.channels, 0, 0, 255));
-    CHECK(0 == channels_set_fg_rgb8(&lr.channels, 0, 0, 0));
-    CHECK(0 == channels_set_bg_rgb8(&ul.channels, 0, 255, 255));
-    CHECK(0 == channels_set_bg_rgb8(&ur.channels, 255, 0, 255));
-    CHECK(0 == channels_set_bg_rgb8(&ll.channels, 255, 255, 0));
-    CHECK(0 == channels_set_bg_rgb8(&lr.channels, 0, 0, 0));
-    CHECK(0 == channels_set_fg_rgb8(&hl.channels, 255, 0, 255));
-    CHECK(0 == channels_set_fg_rgb8(&vl.channels, 255, 255, 255));
-    CHECK(0 == channels_set_bg_rgb8(&hl.channels, 0, 255, 0));
-    CHECK(0 == channels_set_bg_rgb8(&vl.channels, 0, 0, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ul.channels, 255, 0, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ur.channels, 0, 255, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&ll.channels, 0, 0, 255));
+    CHECK(0 == ncchannels_set_fg_rgb8(&lr.channels, 0, 0, 0));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ul.channels, 0, 255, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ur.channels, 255, 0, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&ll.channels, 255, 255, 0));
+    CHECK(0 == ncchannels_set_bg_rgb8(&lr.channels, 0, 0, 0));
+    CHECK(0 == ncchannels_set_fg_rgb8(&hl.channels, 255, 0, 255));
+    CHECK(0 == ncchannels_set_fg_rgb8(&vl.channels, 255, 255, 255));
+    CHECK(0 == ncchannels_set_bg_rgb8(&hl.channels, 0, 255, 0));
+    CHECK(0 == ncchannels_set_bg_rgb8(&vl.channels, 0, 0, 0));
     for(auto y0 = 0 ; y0 < 4 ; ++y0){
       for(auto x0 = 0 ; x0 < 4 ; ++x0){
         CHECK(0 == ncplane_cursor_move_yx(n_, y0 * sidesz, x0 * (sidesz + 1)));
@@ -735,7 +760,9 @@ TEST_CASE("Plane") {
     CHECK(0 == ncplane_cursor_move_yx(n_, 5, 10));
     CHECK(0 < ncplane_putstr(n_, "|🔥|I have not yet ־ begun to hack|🔥|"));
     CHECK(0 == ncplane_cursor_move_yx(n_, 7, 10));
+#ifndef __APPLE__ // FIXME
     CHECK(0 < ncplane_putstr(n_, "㉀㉁㉂㉃㉄㉅㉆㉇㉈㉉㉊㉋㉌㉍㉎㉏㉐㉑㉒㉓㉔㉕㉖㉗㉘㉙㉚㉛㉜㉝㉞㉟"));
+#endif
     CHECK(0 == notcurses_render(nc_));
   }
 
@@ -751,10 +778,11 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ncp = ncplane_create(n_, &nopts);
     REQUIRE(ncp);
-    REQUIRE(0 == cells_rounded_box(ncp, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
+    REQUIRE(0 == nccells_rounded_box(ncp, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
     CHECK(0 == ncplane_box(ncp, &ul, &ur, &ll, &lr, &hl, &vl, y + 1, x + 1, 0));
     CHECK(0 == notcurses_render(nc_));
     // FIXME verify with ncplane_at_cursor_cell()
@@ -773,10 +801,11 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ncp = ncplane_create(n_, &nopts);
     REQUIRE(ncp);
-    REQUIRE(0 == cells_rounded_box(ncp, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
+    REQUIRE(0 == nccells_rounded_box(ncp, 0, 0, &ul, &ur, &ll, &lr, &hl, &vl));
     CHECK(0 == ncplane_box(ncp, &ul, &ur, &ll, &lr, &hl, &vl, y + 1, x + 1, 0));
     CHECK(0 == notcurses_render(nc_));
     CHECK(0 == ncplane_move_yx(ncp, nrows - 3, ncols - 3));
@@ -808,12 +837,12 @@ TEST_CASE("Plane") {
     CHECK(1 == ncplane_at_yx_cell(n_, 0, 0, &c));
     CHECK(cell_simple_p(&c));
     CHECK(htole('C') == c.gcluster);
-    CHECK(0 == channels_set_fg_rgb(&channels, 0x444444));
+    CHECK(0 == ncchannels_set_fg_rgb(&channels, 0x444444));
     CHECK(channels == c.channels);
     CHECK(1 == ncplane_at_yx_cell(n_, 0, 1, &c));
     CHECK(cell_simple_p(&c));
     CHECK(htole('D') == c.gcluster);
-    CHECK(0 == channels_set_fg_rgb(&channels, 0x888888));
+    CHECK(0 == ncchannels_set_fg_rgb(&channels, 0x888888));
     CHECK(channels == c.channels);
     CHECK(0 == notcurses_render(nc_));
   }
@@ -827,6 +856,7 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* n = ncplane_create(n_, &nopts);
     REQUIRE(n);
@@ -856,6 +886,7 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ndom = ncplane_create(n_, &nopts);
     REQUIRE(ndom);
@@ -879,6 +910,7 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ndom = ncplane_create(n_, &nopts);
     REQUIRE(ndom);
@@ -904,6 +936,7 @@ TEST_CASE("Plane") {
       .userptr = nullptr,
       .name = "ndom",
       .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ndom = ncplane_create(n_, &nopts);
     CHECK(ncplane_pile(ndom) == ncplane_pile(n_));
@@ -944,6 +977,7 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = nullptr, .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     struct ncplane* ndom = ncplane_create(n_, &nopts);
     REQUIRE(ndom);
@@ -958,6 +992,7 @@ TEST_CASE("Plane") {
       .rows = 2,
       .cols = 2,
       .userptr = nullptr, .name = "new1", .resizecb = nullptr, .flags = 0,
+      .margin_b = 0, .margin_r = 0,
     };
     auto n1 = ncplane_create(n_, &nopts);
     REQUIRE(n1);
@@ -974,6 +1009,90 @@ TEST_CASE("Plane") {
     ncplane_destroy(n1);
   }
 
+  // you ought not be able to output control characters
+  SUBCASE("DenyControlASCII") {
+    signed char c = 0;
+    c = -1;
+    do{
+      ++c;
+      if(c && !isprint(c)){
+        CHECK(0 > ncplane_putchar_yx(n_, 0, 0, c));
+      }else{
+        CHECK(1 == ncplane_putchar_yx(n_, 0, 0, c));
+      }
+    }while(c != 127);
+  }
+
+  // relative moves
+  SUBCASE("RelativePlaneMoves") {
+    struct ncplane_options nopts{};
+    nopts.x = 2;
+    nopts.y = 2;
+    nopts.rows = 4;
+    nopts.cols = 4;
+    auto n = ncplane_create(n_, &nopts);
+    REQUIRE(nullptr != n);
+    uint64_t channels = NCCHANNELS_INITIALIZER(0, 0xff, 0, 0xff, 0, 0xff);
+    int y, x;
+    ncplane_yx(n, &y, &x);
+    CHECK(y == 2);
+    CHECK(x == 2);
+    CHECK(1 == ncplane_set_base(n, " ", 0, channels));
+    CHECK(0 == notcurses_render(nc_));
+    CHECK(0 == ncplane_moverel(n, -1, 0)); // up
+    ncplane_yx(n, &y, &x);
+    CHECK(y == 1);
+    CHECK(x == 2);
+    CHECK(0 == notcurses_render(nc_));
+    CHECK(0 == ncplane_moverel(n, 2, 0)); // down
+    ncplane_yx(n, &y, &x);
+    CHECK(y == 3);
+    CHECK(x == 2);
+    CHECK(0 == notcurses_render(nc_));
+    CHECK(0 == ncplane_moverel(n, 0, -1)); // left
+    ncplane_yx(n, &y, &x);
+    CHECK(y == 3);
+    CHECK(x == 1);
+    CHECK(0 == notcurses_render(nc_));
+    CHECK(0 == ncplane_moverel(n, 0, 2)); // right
+    ncplane_yx(n, &y, &x);
+    CHECK(y == 3);
+    CHECK(x == 3);
+    CHECK(0 == notcurses_render(nc_));
+    CHECK(0 == ncplane_destroy(n));
+  }
+
+  SUBCASE("ScrollingVirtualCursor") {
+    struct ncplane_options nopts{};
+    nopts.x = 2;
+    nopts.y = 2;
+    nopts.rows = 4;
+    nopts.cols = 20;
+    auto n = ncplane_create(n_, &nopts);
+    REQUIRE(nullptr != n);
+    CHECK(false == ncplane_set_scrolling(n, true));
+    uint64_t channels = NCCHANNELS_INITIALIZER(0, 0xff, 0, 0xff, 0, 0xff);
+    int y, x;
+    CHECK(1 == ncplane_set_base(n, " ", 0, channels));
+    CHECK(0 == notcurses_render(nc_));
+    for(int i = 0 ; i < ncplane_dim_y(n) ; ++i){
+      ncplane_cursor_yx(n, &y, &x);
+      CHECK(i == y);
+      CHECK(0 == x);
+      CHECK(0 < ncplane_putstr(n, "here's a line\n"));
+      CHECK(0 == notcurses_render(nc_));
+    }
+    for(int i = 0 ; i < ncplane_dim_y(n) ; ++i){
+      ncplane_cursor_yx(n, &y, &x);
+      CHECK(ncplane_dim_y(n) - 1 == y);
+      CHECK(0 == x);
+      CHECK(0 < ncplane_putstr(n, "here's a line\n"));
+      CHECK(0 == notcurses_render(nc_));
+    }
+    CHECK(0 == ncplane_destroy(n));
+    CHECK(0 == notcurses_render(nc_));
+  }
+
   CHECK(0 == notcurses_stop(nc_));
 
 }
