@@ -10,9 +10,9 @@ void StainBoard(int dimy, int dimx){
   green = (l / 2) * 0x20;
   const int c1 = level_ % 2 ? high : low;
   const int c2 = level_ % 2 ? low : high;
-  uint64_t tl = CHANNELS_RGB_INITIALIZER(c1, green, c2, c1, green, c2);
-  uint64_t tr = CHANNELS_RGB_INITIALIZER(c2, green, c1, c2, green, c1);
-  uint64_t bl = CHANNELS_RGB_INITIALIZER(c2, green, c1, c2, green, c1);
-  uint64_t br = CHANNELS_RGB_INITIALIZER(c1, green, c2, c1, green, c2);
+  uint64_t tl = NCCHANNELS_INITIALIZER(c1, green, c2, c1, green, c2);
+  uint64_t tr = NCCHANNELS_INITIALIZER(c2, green, c1, c2, green, c1);
+  uint64_t bl = NCCHANNELS_INITIALIZER(c2, green, c1, c2, green, c1);
+  uint64_t br = NCCHANNELS_INITIALIZER(c1, green, c2, c1, green, c2);
   board_->stain(dimy - 2, dimx - 2, tl, tr, bl, br);
 }
