@@ -12,6 +12,7 @@ OLDVERSION="$1"
 VERSION="$2"
 QUIP="$3"
 
+# finalize the date on the most recent version, add any last-minute notes?
 vi NEWS.md
 
 git clean -f -d -x
@@ -19,15 +20,21 @@ git clean -f -d -x
 # Doing general context-free regexery has led several times to heartache. We
 # thus do tightly-coupled, context-sensitive seds for each class of files.
 # Please don't add version numbers where they're not necessary.
+
+# quick sanity checks before and after version update
+grep $OLDVERSION CMakeLists.txt > /dev/null || { echo "Couldn't find OLDVERSION ($OLDVERSION) in CMakeLists.txt" >&2 ; exit 1 ; }
+sed -i -e "s/\(project(notcurses VERSION \)$OLDVERSION/\1$VERSION/" CMakeLists.txt
+grep $VERSION CMakeLists.txt > /dev/null || { echo "Couldn't find VERSION ($VERSION) in CMakeLists.txt" >&2 ; exit 1 ; }
+
 # FIXME we ought probably verify that there has been an actual change, as these
 #       will surely otherwise go out of date.
-sed -i -e "s/\(project(notcurses VERSION \)$OLDVERSION/\1$VERSION/" CMakeLists.txt
 sed -i -e "s/\(PROJECT_NUMBER *= \)$OLDVERSION/\1$VERSION/" doc/Doxyfile
-for i in doc/man/man*/*.md cffi/notcurses-*.md ; do
+for i in doc/man/man*/*.md cffi/notcurses-*.md cffi/ncdirect-*.md; do
   sed -i -e "s/% v$OLDVERSION/% v$VERSION/" "$i"
 done
-sed -i -e "s/(v$OLDVERSION)/(v$VERSION)/" doc/man/index.html
+sed -i -e "s/v$OLDVERSION/v$VERSION/g" doc/man/index.html
 sed -i -e "s/version=\"$OLDVERSION\"/version=\"$VERSION\"/" cffi/setup.py
+sed -i -e "s/version=\"$OLDVERSION\"/version=\"$VERSION\"/" python/setup.py
 sed -i -e "s/^version = \"$OLDVERSION\"$/version = \"$VERSION\"/" rust/Cargo.toml
 sed -i -e "s/atleast_version(\"$OLDVERSION\")/atleast_version(\"$VERSION\")/" rust/build/build.rs
 
@@ -66,7 +73,8 @@ rm $TARBALL.asc
 
 cd "$BUILDDIR"
 sudo make install
-tar czvf notcurses-doc-$VERSION.tar.gz *.1 *.3 *.html
+# restrict to files beginning with n* to leave out shared objects
+tar czvf notcurses-doc-$VERSION.tar.gz n*.1 n*.3 *.html
 github-asset dankamongmen/notcurses upload v$VERSION notcurses-doc-$VERSION.tar.gz
 cd ../cffi
 python3 setup.py sdist
